@@ -18,17 +18,17 @@ class MutatingWebhook(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        admission_review_versions: typing.List[str] = None,
-        client_config: "WebhookClientConfig" = None,
-        failure_policy: str = None,
-        match_policy: str = None,
-        name: str = None,
-        namespace_selector: "LabelSelector" = None,
-        object_selector: "LabelSelector" = None,
-        reinvocation_policy: str = None,
-        rules: typing.List["RuleWithOperations"] = None,
-        side_effects: str = None,
-        timeout_seconds: int = None,
+        admission_review_versions: typing.Optional[typing.List[str]] = None,
+        client_config: typing.Optional["WebhookClientConfig"] = None,
+        failure_policy: typing.Optional[str] = None,
+        match_policy: typing.Optional[str] = None,
+        name: typing.Optional[str] = None,
+        namespace_selector: typing.Optional["LabelSelector"] = None,
+        object_selector: typing.Optional["LabelSelector"] = None,
+        reinvocation_policy: typing.Optional[str] = None,
+        rules: typing.Optional[typing.List["RuleWithOperations"]] = None,
+        side_effects: typing.Optional[str] = None,
+        timeout_seconds: typing.Optional[int] = None,
     ):
         """Create MutatingWebhook instance."""
         super(MutatingWebhook, self).__init__(
@@ -557,8 +557,8 @@ class MutatingWebhookConfiguration(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        webhooks: typing.List["MutatingWebhook"] = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        webhooks: typing.Optional[typing.List["MutatingWebhook"]] = None,
     ):
         """Create MutatingWebhookConfiguration instance."""
         super(MutatingWebhookConfiguration, self).__init__(
@@ -630,7 +630,7 @@ class MutatingWebhookConfiguration(_kuber_definitions.Resource):
             cleaned.append(typing.cast(MutatingWebhook, item))
         self._properties["webhooks"] = cleaned
 
-    def create_resource(self, namespace: "str" = None):
+    def create_resource(self, namespace: typing.Optional["str"] = None):
         """
         Creates the MutatingWebhookConfiguration in the currently
         configured Kubernetes cluster.
@@ -649,7 +649,7 @@ class MutatingWebhookConfiguration(_kuber_definitions.Resource):
             api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(self, namespace: "str" = None):
+    def replace_resource(self, namespace: typing.Optional["str"] = None):
         """
         Replaces the MutatingWebhookConfiguration in the currently
         configured Kubernetes cluster.
@@ -668,7 +668,7 @@ class MutatingWebhookConfiguration(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(self, namespace: "str" = None):
+    def patch_resource(self, namespace: typing.Optional["str"] = None):
         """
         Patches the MutatingWebhookConfiguration in the currently
         configured Kubernetes cluster.
@@ -687,11 +687,11 @@ class MutatingWebhookConfiguration(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(self, namespace: "str" = None):
+    def get_resource_status(self, namespace: typing.Optional["str"] = None):
         """This resource does not have a status."""
         pass
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the MutatingWebhookConfiguration from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -711,7 +711,7 @@ class MutatingWebhookConfiguration(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -740,7 +740,7 @@ class MutatingWebhookConfiguration(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.AdmissionregistrationV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -765,8 +765,8 @@ class MutatingWebhookConfigurationList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["MutatingWebhookConfiguration"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["MutatingWebhookConfiguration"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create MutatingWebhookConfigurationList instance."""
         super(MutatingWebhookConfigurationList, self).__init__(
@@ -842,7 +842,7 @@ class MutatingWebhookConfigurationList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.AdmissionregistrationV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -868,11 +868,11 @@ class RuleWithOperations(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        api_groups: typing.List[str] = None,
-        api_versions: typing.List[str] = None,
-        operations: typing.List[str] = None,
-        resources: typing.List[str] = None,
-        scope: str = None,
+        api_groups: typing.Optional[typing.List[str]] = None,
+        api_versions: typing.Optional[typing.List[str]] = None,
+        operations: typing.Optional[typing.List[str]] = None,
+        resources: typing.Optional[typing.List[str]] = None,
+        scope: typing.Optional[str] = None,
     ):
         """Create RuleWithOperations instance."""
         super(RuleWithOperations, self).__init__(
@@ -1044,10 +1044,10 @@ class ServiceReference(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        name: str = None,
-        namespace: str = None,
-        path: str = None,
-        port: int = None,
+        name: typing.Optional[str] = None,
+        namespace: typing.Optional[str] = None,
+        path: typing.Optional[str] = None,
+        port: typing.Optional[int] = None,
     ):
         """Create ServiceReference instance."""
         super(ServiceReference, self).__init__(
@@ -1155,16 +1155,16 @@ class ValidatingWebhook(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        admission_review_versions: typing.List[str] = None,
-        client_config: "WebhookClientConfig" = None,
-        failure_policy: str = None,
-        match_policy: str = None,
-        name: str = None,
-        namespace_selector: "LabelSelector" = None,
-        object_selector: "LabelSelector" = None,
-        rules: typing.List["RuleWithOperations"] = None,
-        side_effects: str = None,
-        timeout_seconds: int = None,
+        admission_review_versions: typing.Optional[typing.List[str]] = None,
+        client_config: typing.Optional["WebhookClientConfig"] = None,
+        failure_policy: typing.Optional[str] = None,
+        match_policy: typing.Optional[str] = None,
+        name: typing.Optional[str] = None,
+        namespace_selector: typing.Optional["LabelSelector"] = None,
+        object_selector: typing.Optional["LabelSelector"] = None,
+        rules: typing.Optional[typing.List["RuleWithOperations"]] = None,
+        side_effects: typing.Optional[str] = None,
+        timeout_seconds: typing.Optional[int] = None,
     ):
         """Create ValidatingWebhook instance."""
         super(ValidatingWebhook, self).__init__(
@@ -1630,8 +1630,8 @@ class ValidatingWebhookConfiguration(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        webhooks: typing.List["ValidatingWebhook"] = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        webhooks: typing.Optional[typing.List["ValidatingWebhook"]] = None,
     ):
         """Create ValidatingWebhookConfiguration instance."""
         super(ValidatingWebhookConfiguration, self).__init__(
@@ -1704,7 +1704,7 @@ class ValidatingWebhookConfiguration(_kuber_definitions.Resource):
             cleaned.append(typing.cast(ValidatingWebhook, item))
         self._properties["webhooks"] = cleaned
 
-    def create_resource(self, namespace: "str" = None):
+    def create_resource(self, namespace: typing.Optional["str"] = None):
         """
         Creates the ValidatingWebhookConfiguration in the currently
         configured Kubernetes cluster.
@@ -1723,7 +1723,7 @@ class ValidatingWebhookConfiguration(_kuber_definitions.Resource):
             api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(self, namespace: "str" = None):
+    def replace_resource(self, namespace: typing.Optional["str"] = None):
         """
         Replaces the ValidatingWebhookConfiguration in the currently
         configured Kubernetes cluster.
@@ -1742,7 +1742,7 @@ class ValidatingWebhookConfiguration(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(self, namespace: "str" = None):
+    def patch_resource(self, namespace: typing.Optional["str"] = None):
         """
         Patches the ValidatingWebhookConfiguration in the currently
         configured Kubernetes cluster.
@@ -1761,11 +1761,11 @@ class ValidatingWebhookConfiguration(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(self, namespace: "str" = None):
+    def get_resource_status(self, namespace: typing.Optional["str"] = None):
         """This resource does not have a status."""
         pass
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the ValidatingWebhookConfiguration from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -1785,7 +1785,7 @@ class ValidatingWebhookConfiguration(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -1814,7 +1814,7 @@ class ValidatingWebhookConfiguration(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.AdmissionregistrationV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -1839,8 +1839,8 @@ class ValidatingWebhookConfigurationList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["ValidatingWebhookConfiguration"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["ValidatingWebhookConfiguration"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create ValidatingWebhookConfigurationList instance."""
         super(ValidatingWebhookConfigurationList, self).__init__(
@@ -1916,7 +1916,7 @@ class ValidatingWebhookConfigurationList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.AdmissionregistrationV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -1941,9 +1941,9 @@ class WebhookClientConfig(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        ca_bundle: str = None,
-        service: "ServiceReference" = None,
-        url: str = None,
+        ca_bundle: typing.Optional[str] = None,
+        service: typing.Optional["ServiceReference"] = None,
+        url: typing.Optional[str] = None,
     ):
         """Create WebhookClientConfig instance."""
         super(WebhookClientConfig, self).__init__(
