@@ -7,12 +7,12 @@ from kuber import versioning as _versioning
 # kuber library.
 KUBERNETES_VERSION = _versioning.KubernetesVersion(
     label="pre",
-    version="v1.23.0-alpha.3",
+    version="v1.27.0-beta.0",
     major="1",
-    minor="23",
+    minor="27",
     patch="0",
-    pre_release="alpha.3",
+    pre_release="beta.0",
     build="",
-    created_at=_datetime.datetime(2021, 11, 2),
-    commit_sha="90051602459ca81bcdfd91ff3d12ca5bde50a7a7",
+    created_at=_datetime.datetime(2023, 3, 20),
+    commit_sha="a34e37c9963af5944435b736882bfcd1e81f7e09",
 )
