@@ -18,7 +18,7 @@ class Overhead(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        pod_fixed: dict = None,
+        pod_fixed: typing.Optional[dict] = None,
     ):
         """Create Overhead instance."""
         super(Overhead, self).__init__(api_version="node/v1", kind="Overhead")
@@ -32,7 +32,7 @@ class Overhead(_kuber_definitions.Definition):
     @property
     def pod_fixed(self) -> dict:
         """
-        PodFixed represents the fixed resource overhead associated
+        podFixed represents the fixed resource overhead associated
         with running a pod.
         """
         return typing.cast(
@@ -43,7 +43,7 @@ class Overhead(_kuber_definitions.Definition):
     @pod_fixed.setter
     def pod_fixed(self, value: dict):
         """
-        PodFixed represents the fixed resource overhead associated
+        podFixed represents the fixed resource overhead associated
         with running a pod.
         """
         self._properties["podFixed"] = value
@@ -70,10 +70,10 @@ class RuntimeClass(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        handler: str = None,
-        metadata: "ObjectMeta" = None,
-        overhead: "Overhead" = None,
-        scheduling: "Scheduling" = None,
+        handler: typing.Optional[str] = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        overhead: typing.Optional["Overhead"] = None,
+        scheduling: typing.Optional["Scheduling"] = None,
     ):
         """Create RuntimeClass instance."""
         super(RuntimeClass, self).__init__(api_version="node/v1", kind="RuntimeClass")
@@ -95,7 +95,7 @@ class RuntimeClass(_kuber_definitions.Resource):
     @property
     def handler(self) -> str:
         """
-        Handler specifies the underlying runtime and configuration
+        handler specifies the underlying runtime and configuration
         that the CRI implementation will use to handle pods of this
         class. The possible values are specific to the node & CRI
         configuration.  It is assumed that all handlers are
@@ -114,7 +114,7 @@ class RuntimeClass(_kuber_definitions.Resource):
     @handler.setter
     def handler(self, value: str):
         """
-        Handler specifies the underlying runtime and configuration
+        handler specifies the underlying runtime and configuration
         that the CRI implementation will use to handle pods of this
         class. The possible values are specific to the node & CRI
         configuration.  It is assumed that all handlers are
@@ -156,13 +156,11 @@ class RuntimeClass(_kuber_definitions.Resource):
     @property
     def overhead(self) -> "Overhead":
         """
-        Overhead represents the resource overhead associated with
+        overhead represents the resource overhead associated with
         running a pod for a given RuntimeClass. For more details,
         see
          https://kubernetes.io/docs/concepts/scheduling-
         eviction/pod-overhead/
-        This field is in beta starting v1.18 and is only honored by
-        servers that enable the PodOverhead feature.
         """
         return typing.cast(
             "Overhead",
@@ -172,13 +170,11 @@ class RuntimeClass(_kuber_definitions.Resource):
     @overhead.setter
     def overhead(self, value: typing.Union["Overhead", dict]):
         """
-        Overhead represents the resource overhead associated with
+        overhead represents the resource overhead associated with
         running a pod for a given RuntimeClass. For more details,
         see
          https://kubernetes.io/docs/concepts/scheduling-
         eviction/pod-overhead/
-        This field is in beta starting v1.18 and is only honored by
-        servers that enable the PodOverhead feature.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -190,7 +186,7 @@ class RuntimeClass(_kuber_definitions.Resource):
     @property
     def scheduling(self) -> "Scheduling":
         """
-        Scheduling holds the scheduling constraints to ensure that
+        scheduling holds the scheduling constraints to ensure that
         pods running with this RuntimeClass are scheduled to nodes
         that support it. If scheduling is nil, this RuntimeClass is
         assumed to be supported by all nodes.
@@ -203,7 +199,7 @@ class RuntimeClass(_kuber_definitions.Resource):
     @scheduling.setter
     def scheduling(self, value: typing.Union["Scheduling", dict]):
         """
-        Scheduling holds the scheduling constraints to ensure that
+        scheduling holds the scheduling constraints to ensure that
         pods running with this RuntimeClass are scheduled to nodes
         that support it. If scheduling is nil, this RuntimeClass is
         assumed to be supported by all nodes.
@@ -215,7 +211,7 @@ class RuntimeClass(_kuber_definitions.Resource):
             )
         self._properties["scheduling"] = value
 
-    def create_resource(self, namespace: "str" = None):
+    def create_resource(self, namespace: typing.Optional["str"] = None):
         """
         Creates the RuntimeClass in the currently
         configured Kubernetes cluster.
@@ -231,7 +227,7 @@ class RuntimeClass(_kuber_definitions.Resource):
             api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(self, namespace: "str" = None):
+    def replace_resource(self, namespace: typing.Optional["str"] = None):
         """
         Replaces the RuntimeClass in the currently
         configured Kubernetes cluster.
@@ -247,7 +243,7 @@ class RuntimeClass(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(self, namespace: "str" = None):
+    def patch_resource(self, namespace: typing.Optional["str"] = None):
         """
         Patches the RuntimeClass in the currently
         configured Kubernetes cluster.
@@ -263,11 +259,11 @@ class RuntimeClass(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(self, namespace: "str" = None):
+    def get_resource_status(self, namespace: typing.Optional["str"] = None):
         """This resource does not have a status."""
         pass
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the RuntimeClass from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -287,7 +283,7 @@ class RuntimeClass(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -316,7 +312,7 @@ class RuntimeClass(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.NodeV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -340,8 +336,8 @@ class RuntimeClassList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["RuntimeClass"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["RuntimeClass"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create RuntimeClassList instance."""
         super(RuntimeClassList, self).__init__(
@@ -361,7 +357,7 @@ class RuntimeClassList(_kuber_definitions.Collection):
     @property
     def items(self) -> typing.List["RuntimeClass"]:
         """
-        Items is a list of schema objects.
+        items is a list of schema objects.
         """
         return typing.cast(
             typing.List["RuntimeClass"],
@@ -373,7 +369,7 @@ class RuntimeClassList(_kuber_definitions.Collection):
         self, value: typing.Union[typing.List["RuntimeClass"], typing.List[dict]]
     ):
         """
-        Items is a list of schema objects.
+        items is a list of schema objects.
         """
         cleaned: typing.List[RuntimeClass] = []
         for item in value:
@@ -413,7 +409,7 @@ class RuntimeClassList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.NodeV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -438,8 +434,8 @@ class Scheduling(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        node_selector: dict = None,
-        tolerations: typing.List["Toleration"] = None,
+        node_selector: typing.Optional[dict] = None,
+        tolerations: typing.Optional[typing.List["Toleration"]] = None,
     ):
         """Create Scheduling instance."""
         super(Scheduling, self).__init__(api_version="node/v1", kind="Scheduling")
