@@ -6,11 +6,207 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_19.meta_v1 import LabelSelector  # noqa: F401
-from kuber.v1_19.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_19.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_19.meta_v1 import Status  # noqa: F401
-from kuber.v1_19.meta_v1 import StatusDetails  # noqa: F401
+from kuber.v1_23.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_23.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_23.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_23.meta_v1 import Status  # noqa: F401
+from kuber.v1_23.meta_v1 import StatusDetails  # noqa: F401
+
+
+class ContainerResourceMetricSource(_kuber_definitions.Definition):
+    """
+    ContainerResourceMetricSource indicates how to scale on a
+    resource metric known to Kubernetes, as specified in
+    requests and limits, describing each pod in the current
+    scale target (e.g. CPU or memory).  The values will be
+    averaged together before being compared to the target.  Such
+    metrics are built in to Kubernetes, and have special scaling
+    options on top of those available to normal per-pod metrics
+    using the "pods" source.  Only one "target" type should be
+    set.
+    """
+
+    def __init__(
+        self,
+        container: typing.Optional[str] = None,
+        name: typing.Optional[str] = None,
+        target: typing.Optional["MetricTarget"] = None,
+    ):
+        """Create ContainerResourceMetricSource instance."""
+        super(ContainerResourceMetricSource, self).__init__(
+            api_version="autoscaling/v2beta2", kind="ContainerResourceMetricSource"
+        )
+        self._properties = {
+            "container": container if container is not None else "",
+            "name": name if name is not None else "",
+            "target": target if target is not None else MetricTarget(),
+        }
+        self._types = {
+            "container": (str, None),
+            "name": (str, None),
+            "target": (MetricTarget, None),
+        }
+
+    @property
+    def container(self) -> str:
+        """
+        container is the name of the container in the pods of the
+        scaling target
+        """
+        return typing.cast(
+            str,
+            self._properties.get("container"),
+        )
+
+    @container.setter
+    def container(self, value: str):
+        """
+        container is the name of the container in the pods of the
+        scaling target
+        """
+        self._properties["container"] = value
+
+    @property
+    def name(self) -> str:
+        """
+        name is the name of the resource in question.
+        """
+        return typing.cast(
+            str,
+            self._properties.get("name"),
+        )
+
+    @name.setter
+    def name(self, value: str):
+        """
+        name is the name of the resource in question.
+        """
+        self._properties["name"] = value
+
+    @property
+    def target(self) -> "MetricTarget":
+        """
+        target specifies the target value for the given metric
+        """
+        return typing.cast(
+            "MetricTarget",
+            self._properties.get("target"),
+        )
+
+    @target.setter
+    def target(self, value: typing.Union["MetricTarget", dict]):
+        """
+        target specifies the target value for the given metric
+        """
+        if isinstance(value, dict):
+            value = typing.cast(
+                MetricTarget,
+                MetricTarget().from_dict(value),
+            )
+        self._properties["target"] = value
+
+    def __enter__(self) -> "ContainerResourceMetricSource":
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        return False
+
+
+class ContainerResourceMetricStatus(_kuber_definitions.Definition):
+    """
+    ContainerResourceMetricStatus indicates the current value of
+    a resource metric known to Kubernetes, as specified in
+    requests and limits, describing a single container in each
+    pod in the current scale target (e.g. CPU or memory).  Such
+    metrics are built in to Kubernetes, and have special scaling
+    options on top of those available to normal per-pod metrics
+    using the "pods" source.
+    """
+
+    def __init__(
+        self,
+        container: typing.Optional[str] = None,
+        current: typing.Optional["MetricValueStatus"] = None,
+        name: typing.Optional[str] = None,
+    ):
+        """Create ContainerResourceMetricStatus instance."""
+        super(ContainerResourceMetricStatus, self).__init__(
+            api_version="autoscaling/v2beta2", kind="ContainerResourceMetricStatus"
+        )
+        self._properties = {
+            "container": container if container is not None else "",
+            "current": current if current is not None else MetricValueStatus(),
+            "name": name if name is not None else "",
+        }
+        self._types = {
+            "container": (str, None),
+            "current": (MetricValueStatus, None),
+            "name": (str, None),
+        }
+
+    @property
+    def container(self) -> str:
+        """
+        Container is the name of the container in the pods of the
+        scaling target
+        """
+        return typing.cast(
+            str,
+            self._properties.get("container"),
+        )
+
+    @container.setter
+    def container(self, value: str):
+        """
+        Container is the name of the container in the pods of the
+        scaling target
+        """
+        self._properties["container"] = value
+
+    @property
+    def current(self) -> "MetricValueStatus":
+        """
+        current contains the current value for the given metric
+        """
+        return typing.cast(
+            "MetricValueStatus",
+            self._properties.get("current"),
+        )
+
+    @current.setter
+    def current(self, value: typing.Union["MetricValueStatus", dict]):
+        """
+        current contains the current value for the given metric
+        """
+        if isinstance(value, dict):
+            value = typing.cast(
+                MetricValueStatus,
+                MetricValueStatus().from_dict(value),
+            )
+        self._properties["current"] = value
+
+    @property
+    def name(self) -> str:
+        """
+        Name is the name of the resource in question.
+        """
+        return typing.cast(
+            str,
+            self._properties.get("name"),
+        )
+
+    @name.setter
+    def name(self, value: str):
+        """
+        Name is the name of the resource in question.
+        """
+        self._properties["name"] = value
+
+    def __enter__(self) -> "ContainerResourceMetricStatus":
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        return False
 
 
 class CrossVersionObjectReference(_kuber_definitions.Definition):
@@ -21,9 +217,9 @@ class CrossVersionObjectReference(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        api_version: str = None,
-        kind: str = None,
-        name: str = None,
+        api_version: typing.Optional[str] = None,
+        kind: typing.Optional[str] = None,
+        name: typing.Optional[str] = None,
     ):
         """Create CrossVersionObjectReference instance."""
         super(CrossVersionObjectReference, self).__init__(
@@ -114,8 +310,8 @@ class ExternalMetricSource(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        metric: "MetricIdentifier" = None,
-        target: "MetricTarget" = None,
+        metric: typing.Optional["MetricIdentifier"] = None,
+        target: typing.Optional["MetricTarget"] = None,
     ):
         """Create ExternalMetricSource instance."""
         super(ExternalMetricSource, self).__init__(
@@ -189,8 +385,8 @@ class ExternalMetricStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        current: "MetricValueStatus" = None,
-        metric: "MetricIdentifier" = None,
+        current: typing.Optional["MetricValueStatus"] = None,
+        metric: typing.Optional["MetricIdentifier"] = None,
     ):
         """Create ExternalMetricStatus instance."""
         super(ExternalMetricStatus, self).__init__(
@@ -264,9 +460,9 @@ class HPAScalingPolicy(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        period_seconds: int = None,
-        type_: str = None,
-        value: int = None,
+        period_seconds: typing.Optional[int] = None,
+        type_: typing.Optional[str] = None,
+        value: typing.Optional[int] = None,
     ):
         """Create HPAScalingPolicy instance."""
         super(HPAScalingPolicy, self).__init__(
@@ -360,9 +556,9 @@ class HPAScalingRules(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        policies: typing.List["HPAScalingPolicy"] = None,
-        select_policy: str = None,
-        stabilization_window_seconds: int = None,
+        policies: typing.Optional[typing.List["HPAScalingPolicy"]] = None,
+        select_policy: typing.Optional[str] = None,
+        stabilization_window_seconds: typing.Optional[int] = None,
     ):
         """Create HPAScalingRules instance."""
         super(HPAScalingRules, self).__init__(
@@ -479,9 +675,9 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        spec: "HorizontalPodAutoscalerSpec" = None,
-        status: "HorizontalPodAutoscalerStatus" = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        spec: typing.Optional["HorizontalPodAutoscalerSpec"] = None,
+        status: typing.Optional["HorizontalPodAutoscalerStatus"] = None,
     ):
         """Create HorizontalPodAutoscaler instance."""
         super(HorizontalPodAutoscaler, self).__init__(
@@ -577,7 +773,7 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
         self._properties["status"] = value
 
     def create_resource(
-        self, namespace: "str" = None
+        self, namespace: typing.Optional["str"] = None
     ) -> "HorizontalPodAutoscalerStatus":
         """
         Creates the HorizontalPodAutoscaler in the currently
@@ -604,7 +800,7 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
         return output
 
     def replace_resource(
-        self, namespace: "str" = None
+        self, namespace: typing.Optional["str"] = None
     ) -> "HorizontalPodAutoscalerStatus":
         """
         Replaces the HorizontalPodAutoscaler in the currently
@@ -631,7 +827,7 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
         return output
 
     def patch_resource(
-        self, namespace: "str" = None
+        self, namespace: typing.Optional["str"] = None
     ) -> "HorizontalPodAutoscalerStatus":
         """
         Patches the HorizontalPodAutoscaler in the currently
@@ -658,7 +854,7 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
         return output
 
     def get_resource_status(
-        self, namespace: "str" = None
+        self, namespace: typing.Optional["str"] = None
     ) -> "HorizontalPodAutoscalerStatus":
         """
         Returns status information about the given resource within the cluster.
@@ -682,7 +878,7 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the HorizontalPodAutoscaler from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -702,7 +898,7 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -731,7 +927,7 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.AutoscalingV2beta2Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -757,8 +953,8 @@ class HorizontalPodAutoscalerBehavior(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        scale_down: "HPAScalingRules" = None,
-        scale_up: "HPAScalingRules" = None,
+        scale_down: typing.Optional["HPAScalingRules"] = None,
+        scale_up: typing.Optional["HPAScalingRules"] = None,
     ):
         """Create HorizontalPodAutoscalerBehavior instance."""
         super(HorizontalPodAutoscalerBehavior, self).__init__(
@@ -846,11 +1042,11 @@ class HorizontalPodAutoscalerCondition(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        last_transition_time: str = None,
-        message: str = None,
-        reason: str = None,
-        status: str = None,
-        type_: str = None,
+        last_transition_time: typing.Optional[str] = None,
+        message: typing.Optional[str] = None,
+        reason: typing.Optional[str] = None,
+        status: typing.Optional[str] = None,
+        type_: typing.Optional[str] = None,
     ):
         """Create HorizontalPodAutoscalerCondition instance."""
         super(HorizontalPodAutoscalerCondition, self).__init__(
@@ -983,8 +1179,8 @@ class HorizontalPodAutoscalerList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["HorizontalPodAutoscaler"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["HorizontalPodAutoscaler"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create HorizontalPodAutoscalerList instance."""
         super(HorizontalPodAutoscalerList, self).__init__(
@@ -1053,7 +1249,7 @@ class HorizontalPodAutoscalerList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.AutoscalingV2beta2Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -1078,11 +1274,11 @@ class HorizontalPodAutoscalerSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        behavior: "HorizontalPodAutoscalerBehavior" = None,
-        max_replicas: int = None,
-        metrics: typing.List["MetricSpec"] = None,
-        min_replicas: int = None,
-        scale_target_ref: "CrossVersionObjectReference" = None,
+        behavior: typing.Optional["HorizontalPodAutoscalerBehavior"] = None,
+        max_replicas: typing.Optional[int] = None,
+        metrics: typing.Optional[typing.List["MetricSpec"]] = None,
+        min_replicas: typing.Optional[int] = None,
+        scale_target_ref: typing.Optional["CrossVersionObjectReference"] = None,
     ):
         """Create HorizontalPodAutoscalerSpec instance."""
         super(HorizontalPodAutoscalerSpec, self).__init__(
@@ -1271,12 +1467,14 @@ class HorizontalPodAutoscalerStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        conditions: typing.List["HorizontalPodAutoscalerCondition"] = None,
-        current_metrics: typing.List["MetricStatus"] = None,
-        current_replicas: int = None,
-        desired_replicas: int = None,
-        last_scale_time: str = None,
-        observed_generation: int = None,
+        conditions: typing.Optional[
+            typing.List["HorizontalPodAutoscalerCondition"]
+        ] = None,
+        current_metrics: typing.Optional[typing.List["MetricStatus"]] = None,
+        current_replicas: typing.Optional[int] = None,
+        desired_replicas: typing.Optional[int] = None,
+        last_scale_time: typing.Optional[str] = None,
+        observed_generation: typing.Optional[int] = None,
     ):
         """Create HorizontalPodAutoscalerStatus instance."""
         super(HorizontalPodAutoscalerStatus, self).__init__(
@@ -1469,8 +1667,8 @@ class MetricIdentifier(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        name: str = None,
-        selector: "LabelSelector" = None,
+        name: typing.Optional[str] = None,
+        selector: typing.Optional["LabelSelector"] = None,
     ):
         """Create MetricIdentifier instance."""
         super(MetricIdentifier, self).__init__(
@@ -1548,17 +1746,21 @@ class MetricSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        external: "ExternalMetricSource" = None,
-        object_: "ObjectMetricSource" = None,
-        pods: "PodsMetricSource" = None,
-        resource: "ResourceMetricSource" = None,
-        type_: str = None,
+        container_resource: typing.Optional["ContainerResourceMetricSource"] = None,
+        external: typing.Optional["ExternalMetricSource"] = None,
+        object_: typing.Optional["ObjectMetricSource"] = None,
+        pods: typing.Optional["PodsMetricSource"] = None,
+        resource: typing.Optional["ResourceMetricSource"] = None,
+        type_: typing.Optional[str] = None,
     ):
         """Create MetricSpec instance."""
         super(MetricSpec, self).__init__(
             api_version="autoscaling/v2beta2", kind="MetricSpec"
         )
         self._properties = {
+            "containerResource": container_resource
+            if container_resource is not None
+            else ContainerResourceMetricSource(),
             "external": external if external is not None else ExternalMetricSource(),
             "object": object_ if object_ is not None else ObjectMetricSource(),
             "pods": pods if pods is not None else PodsMetricSource(),
@@ -1566,6 +1768,7 @@ class MetricSpec(_kuber_definitions.Definition):
             "type": type_ if type_ is not None else "",
         }
         self._types = {
+            "containerResource": (ContainerResourceMetricSource, None),
             "external": (ExternalMetricSource, None),
             "object": (ObjectMetricSource, None),
             "pods": (PodsMetricSource, None),
@@ -1573,6 +1776,44 @@ class MetricSpec(_kuber_definitions.Definition):
             "type": (str, None),
         }
 
+    @property
+    def container_resource(self) -> "ContainerResourceMetricSource":
+        """
+        container resource refers to a resource metric (such as
+        those specified in requests and limits) known to Kubernetes
+        describing a single container in each pod of the current
+        scale target (e.g. CPU or memory). Such metrics are built in
+        to Kubernetes, and have special scaling options on top of
+        those available to normal per-pod metrics using the "pods"
+        source. This is an alpha feature and can be enabled by the
+        HPAContainerMetrics feature flag.
+        """
+        return typing.cast(
+            "ContainerResourceMetricSource",
+            self._properties.get("containerResource"),
+        )
+
+    @container_resource.setter
+    def container_resource(
+        self, value: typing.Union["ContainerResourceMetricSource", dict]
+    ):
+        """
+        container resource refers to a resource metric (such as
+        those specified in requests and limits) known to Kubernetes
+        describing a single container in each pod of the current
+        scale target (e.g. CPU or memory). Such metrics are built in
+        to Kubernetes, and have special scaling options on top of
+        those available to normal per-pod metrics using the "pods"
+        source. This is an alpha feature and can be enabled by the
+        HPAContainerMetrics feature flag.
+        """
+        if isinstance(value, dict):
+            value = typing.cast(
+                ContainerResourceMetricSource,
+                ContainerResourceMetricSource().from_dict(value),
+            )
+        self._properties["containerResource"] = value
+
     @property
     def external(self) -> "ExternalMetricSource":
         """
@@ -1693,8 +1934,10 @@ class MetricSpec(_kuber_definitions.Definition):
     def type_(self) -> str:
         """
         type is the type of metric source.  It should be one of
-        "Object", "Pods" or "Resource", each mapping to a matching
-        field in the object.
+        "ContainerResource", "External", "Object", "Pods" or
+        "Resource", each mapping to a matching field in the object.
+        Note: "ContainerResource" type is available on when the
+        feature-gate HPAContainerMetrics is enabled
         """
         return typing.cast(
             str,
@@ -1705,8 +1948,10 @@ class MetricSpec(_kuber_definitions.Definition):
     def type_(self, value: str):
         """
         type is the type of metric source.  It should be one of
-        "Object", "Pods" or "Resource", each mapping to a matching
-        field in the object.
+        "ContainerResource", "External", "Object", "Pods" or
+        "Resource", each mapping to a matching field in the object.
+        Note: "ContainerResource" type is available on when the
+        feature-gate HPAContainerMetrics is enabled
         """
         self._properties["type"] = value
 
@@ -1725,17 +1970,21 @@ class MetricStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        external: "ExternalMetricStatus" = None,
-        object_: "ObjectMetricStatus" = None,
-        pods: "PodsMetricStatus" = None,
-        resource: "ResourceMetricStatus" = None,
-        type_: str = None,
+        container_resource: typing.Optional["ContainerResourceMetricStatus"] = None,
+        external: typing.Optional["ExternalMetricStatus"] = None,
+        object_: typing.Optional["ObjectMetricStatus"] = None,
+        pods: typing.Optional["PodsMetricStatus"] = None,
+        resource: typing.Optional["ResourceMetricStatus"] = None,
+        type_: typing.Optional[str] = None,
     ):
         """Create MetricStatus instance."""
         super(MetricStatus, self).__init__(
             api_version="autoscaling/v2beta2", kind="MetricStatus"
         )
         self._properties = {
+            "containerResource": container_resource
+            if container_resource is not None
+            else ContainerResourceMetricStatus(),
             "external": external if external is not None else ExternalMetricStatus(),
             "object": object_ if object_ is not None else ObjectMetricStatus(),
             "pods": pods if pods is not None else PodsMetricStatus(),
@@ -1743,6 +1992,7 @@ class MetricStatus(_kuber_definitions.Definition):
             "type": type_ if type_ is not None else "",
         }
         self._types = {
+            "containerResource": (ContainerResourceMetricStatus, None),
             "external": (ExternalMetricStatus, None),
             "object": (ObjectMetricStatus, None),
             "pods": (PodsMetricStatus, None),
@@ -1750,6 +2000,42 @@ class MetricStatus(_kuber_definitions.Definition):
             "type": (str, None),
         }
 
+    @property
+    def container_resource(self) -> "ContainerResourceMetricStatus":
+        """
+        container resource refers to a resource metric (such as
+        those specified in requests and limits) known to Kubernetes
+        describing a single container in each pod in the current
+        scale target (e.g. CPU or memory). Such metrics are built in
+        to Kubernetes, and have special scaling options on top of
+        those available to normal per-pod metrics using the "pods"
+        source.
+        """
+        return typing.cast(
+            "ContainerResourceMetricStatus",
+            self._properties.get("containerResource"),
+        )
+
+    @container_resource.setter
+    def container_resource(
+        self, value: typing.Union["ContainerResourceMetricStatus", dict]
+    ):
+        """
+        container resource refers to a resource metric (such as
+        those specified in requests and limits) known to Kubernetes
+        describing a single container in each pod in the current
+        scale target (e.g. CPU or memory). Such metrics are built in
+        to Kubernetes, and have special scaling options on top of
+        those available to normal per-pod metrics using the "pods"
+        source.
+        """
+        if isinstance(value, dict):
+            value = typing.cast(
+                ContainerResourceMetricStatus,
+                ContainerResourceMetricStatus().from_dict(value),
+            )
+        self._properties["containerResource"] = value
+
     @property
     def external(self) -> "ExternalMetricStatus":
         """
@@ -1870,8 +2156,10 @@ class MetricStatus(_kuber_definitions.Definition):
     def type_(self) -> str:
         """
         type is the type of metric source.  It will be one of
-        "Object", "Pods" or "Resource", each corresponds to a
-        matching field in the object.
+        "ContainerResource", "External", "Object", "Pods" or
+        "Resource", each corresponds to a matching field in the
+        object. Note: "ContainerResource" type is available on when
+        the feature-gate HPAContainerMetrics is enabled
         """
         return typing.cast(
             str,
@@ -1882,8 +2170,10 @@ class MetricStatus(_kuber_definitions.Definition):
     def type_(self, value: str):
         """
         type is the type of metric source.  It will be one of
-        "Object", "Pods" or "Resource", each corresponds to a
-        matching field in the object.
+        "ContainerResource", "External", "Object", "Pods" or
+        "Resource", each corresponds to a matching field in the
+        object. Note: "ContainerResource" type is available on when
+        the feature-gate HPAContainerMetrics is enabled
         """
         self._properties["type"] = value
 
@@ -1902,10 +2192,10 @@ class MetricTarget(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        average_utilization: int = None,
-        average_value: typing.Union[str, int, None] = None,
-        type_: str = None,
-        value: typing.Union[str, int, None] = None,
+        average_utilization: typing.Optional[int] = None,
+        average_value: typing.Optional[typing.Union[str, int, None]] = None,
+        type_: typing.Optional[str] = None,
+        value: typing.Optional[typing.Union[str, int, None]] = None,
     ):
         """Create MetricTarget instance."""
         super(MetricTarget, self).__init__(
@@ -2014,9 +2304,9 @@ class MetricValueStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        average_utilization: int = None,
-        average_value: typing.Union[str, int, None] = None,
-        value: typing.Union[str, int, None] = None,
+        average_utilization: typing.Optional[int] = None,
+        average_value: typing.Optional[typing.Union[str, int, None]] = None,
+        value: typing.Optional[typing.Union[str, int, None]] = None,
     ):
         """Create MetricValueStatus instance."""
         super(MetricValueStatus, self).__init__(
@@ -2106,9 +2396,9 @@ class ObjectMetricSource(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        described_object: "CrossVersionObjectReference" = None,
-        metric: "MetricIdentifier" = None,
-        target: "MetricTarget" = None,
+        described_object: typing.Optional["CrossVersionObjectReference"] = None,
+        metric: typing.Optional["MetricIdentifier"] = None,
+        target: typing.Optional["MetricTarget"] = None,
     ):
         """Create ObjectMetricSource instance."""
         super(ObjectMetricSource, self).__init__(
@@ -2207,9 +2497,9 @@ class ObjectMetricStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        current: "MetricValueStatus" = None,
-        described_object: "CrossVersionObjectReference" = None,
-        metric: "MetricIdentifier" = None,
+        current: typing.Optional["MetricValueStatus"] = None,
+        described_object: typing.Optional["CrossVersionObjectReference"] = None,
+        metric: typing.Optional["MetricIdentifier"] = None,
     ):
         """Create ObjectMetricStatus instance."""
         super(ObjectMetricStatus, self).__init__(
@@ -2310,8 +2600,8 @@ class PodsMetricSource(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        metric: "MetricIdentifier" = None,
-        target: "MetricTarget" = None,
+        metric: typing.Optional["MetricIdentifier"] = None,
+        target: typing.Optional["MetricTarget"] = None,
     ):
         """Create PodsMetricSource instance."""
         super(PodsMetricSource, self).__init__(
@@ -2386,8 +2676,8 @@ class PodsMetricStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        current: "MetricValueStatus" = None,
-        metric: "MetricIdentifier" = None,
+        current: typing.Optional["MetricValueStatus"] = None,
+        metric: typing.Optional["MetricIdentifier"] = None,
     ):
         """Create PodsMetricStatus instance."""
         super(PodsMetricStatus, self).__init__(
@@ -2467,8 +2757,8 @@ class ResourceMetricSource(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        name: str = None,
-        target: "MetricTarget" = None,
+        name: typing.Optional[str] = None,
+        target: typing.Optional["MetricTarget"] = None,
     ):
         """Create ResourceMetricSource instance."""
         super(ResourceMetricSource, self).__init__(
@@ -2542,8 +2832,8 @@ class ResourceMetricStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        current: "MetricValueStatus" = None,
-        name: str = None,
+        current: typing.Optional["MetricValueStatus"] = None,
+        name: typing.Optional[str] = None,
     ):
         """Create ResourceMetricStatus instance."""
         super(ResourceMetricStatus, self).__init__(
