@@ -5,9 +5,9 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_22.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_22.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_22.core_v1 import ObjectReference  # noqa: F401
+from kuber.v1_23.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_23.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_23.core_v1 import ObjectReference  # noqa: F401
 
 
 class Endpoint(_kuber_definitions.Definition):
@@ -18,13 +18,13 @@ class Endpoint(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        addresses: typing.List[str] = None,
-        conditions: "EndpointConditions" = None,
-        hints: "EndpointHints" = None,
-        hostname: str = None,
-        node_name: str = None,
-        target_ref: "ObjectReference" = None,
-        topology: dict = None,
+        addresses: typing.Optional[typing.List[str]] = None,
+        conditions: typing.Optional["EndpointConditions"] = None,
+        hints: typing.Optional["EndpointHints"] = None,
+        hostname: typing.Optional[str] = None,
+        node_name: typing.Optional[str] = None,
+        target_ref: typing.Optional["ObjectReference"] = None,
+        topology: typing.Optional[dict] = None,
     ):
         """Create Endpoint instance."""
         super(Endpoint, self).__init__(api_version="discovery/v1beta1", kind="Endpoint")
@@ -268,9 +268,9 @@ class EndpointConditions(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        ready: bool = None,
-        serving: bool = None,
-        terminating: bool = None,
+        ready: typing.Optional[bool] = None,
+        serving: typing.Optional[bool] = None,
+        terminating: typing.Optional[bool] = None,
     ):
         """Create EndpointConditions instance."""
         super(EndpointConditions, self).__init__(
@@ -381,7 +381,7 @@ class EndpointHints(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        for_zones: typing.List["ForZone"] = None,
+        for_zones: typing.Optional[typing.List["ForZone"]] = None,
     ):
         """Create EndpointHints instance."""
         super(EndpointHints, self).__init__(
@@ -437,10 +437,10 @@ class EndpointPort(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        app_protocol: str = None,
-        name: str = None,
-        port: int = None,
-        protocol: str = None,
+        app_protocol: typing.Optional[str] = None,
+        name: typing.Optional[str] = None,
+        port: typing.Optional[int] = None,
+        protocol: typing.Optional[str] = None,
     ):
         """Create EndpointPort instance."""
         super(EndpointPort, self).__init__(
@@ -574,10 +574,10 @@ class EndpointSlice(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        address_type: str = None,
-        endpoints: typing.List["Endpoint"] = None,
-        metadata: "ObjectMeta" = None,
-        ports: typing.List["EndpointPort"] = None,
+        address_type: typing.Optional[str] = None,
+        endpoints: typing.Optional[typing.List["Endpoint"]] = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        ports: typing.Optional[typing.List["EndpointPort"]] = None,
     ):
         """Create EndpointSlice instance."""
         super(EndpointSlice, self).__init__(
@@ -713,7 +713,7 @@ class EndpointSlice(_kuber_definitions.Resource):
             cleaned.append(typing.cast(EndpointPort, item))
         self._properties["ports"] = cleaned
 
-    def create_resource(self, namespace: "str" = None):
+    def create_resource(self, namespace: typing.Optional["str"] = None):
         """
         Creates the EndpointSlice in the currently
         configured Kubernetes cluster.
@@ -729,7 +729,7 @@ class EndpointSlice(_kuber_definitions.Resource):
             api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(self, namespace: "str" = None):
+    def replace_resource(self, namespace: typing.Optional["str"] = None):
         """
         Replaces the EndpointSlice in the currently
         configured Kubernetes cluster.
@@ -745,7 +745,7 @@ class EndpointSlice(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(self, namespace: "str" = None):
+    def patch_resource(self, namespace: typing.Optional["str"] = None):
         """
         Patches the EndpointSlice in the currently
         configured Kubernetes cluster.
@@ -761,11 +761,11 @@ class EndpointSlice(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(self, namespace: "str" = None):
+    def get_resource_status(self, namespace: typing.Optional["str"] = None):
         """This resource does not have a status."""
         pass
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the EndpointSlice from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -785,7 +785,7 @@ class EndpointSlice(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -814,7 +814,7 @@ class EndpointSlice(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.DiscoveryV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -838,8 +838,8 @@ class EndpointSliceList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["EndpointSlice"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["EndpointSlice"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create EndpointSliceList instance."""
         super(EndpointSliceList, self).__init__(
@@ -907,7 +907,7 @@ class EndpointSliceList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.DiscoveryV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -932,7 +932,7 @@ class ForZone(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        name: str = None,
+        name: typing.Optional[str] = None,
     ):
         """Create ForZone instance."""
         super(ForZone, self).__init__(api_version="discovery/v1beta1", kind="ForZone")
