@@ -5,9 +5,9 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_20.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_20.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_20.core_v1 import Toleration  # noqa: F401
+from kuber.v1_23.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_23.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_23.core_v1 import Toleration  # noqa: F401
 
 
 class Overhead(_kuber_definitions.Definition):
@@ -18,7 +18,7 @@ class Overhead(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        pod_fixed: dict = None,
+        pod_fixed: typing.Optional[dict] = None,
     ):
         """Create Overhead instance."""
         super(Overhead, self).__init__(api_version="node/v1alpha1", kind="Overhead")
@@ -64,14 +64,14 @@ class RuntimeClass(_kuber_definitions.Resource):
     cluster provisioner, and referenced in the PodSpec. The
     Kubelet is responsible for resolving the RuntimeClassName
     reference before running the pod.  For more details, see
-    https://git.k8s.io/enhancements/keps/sig-node/runtime-
-    class.md
+    https://git.k8s.io/enhancements/keps/sig-node/585-runtime-
+    class
     """
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        spec: "RuntimeClassSpec" = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        spec: typing.Optional["RuntimeClassSpec"] = None,
     ):
         """Create RuntimeClass instance."""
         super(RuntimeClass, self).__init__(
@@ -140,7 +140,7 @@ class RuntimeClass(_kuber_definitions.Resource):
             )
         self._properties["spec"] = value
 
-    def create_resource(self, namespace: "str" = None):
+    def create_resource(self, namespace: typing.Optional["str"] = None):
         """
         Creates the RuntimeClass in the currently
         configured Kubernetes cluster.
@@ -156,7 +156,7 @@ class RuntimeClass(_kuber_definitions.Resource):
             api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(self, namespace: "str" = None):
+    def replace_resource(self, namespace: typing.Optional["str"] = None):
         """
         Replaces the RuntimeClass in the currently
         configured Kubernetes cluster.
@@ -172,7 +172,7 @@ class RuntimeClass(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(self, namespace: "str" = None):
+    def patch_resource(self, namespace: typing.Optional["str"] = None):
         """
         Patches the RuntimeClass in the currently
         configured Kubernetes cluster.
@@ -188,11 +188,11 @@ class RuntimeClass(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(self, namespace: "str" = None):
+    def get_resource_status(self, namespace: typing.Optional["str"] = None):
         """This resource does not have a status."""
         pass
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the RuntimeClass from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -212,7 +212,7 @@ class RuntimeClass(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -241,7 +241,7 @@ class RuntimeClass(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.NodeV1alpha1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -265,8 +265,8 @@ class RuntimeClassList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["RuntimeClass"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["RuntimeClass"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create RuntimeClassList instance."""
         super(RuntimeClassList, self).__init__(
@@ -338,7 +338,7 @@ class RuntimeClassList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.NodeV1alpha1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -367,9 +367,9 @@ class RuntimeClassSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        overhead: "Overhead" = None,
-        runtime_handler: str = None,
-        scheduling: "Scheduling" = None,
+        overhead: typing.Optional["Overhead"] = None,
+        runtime_handler: typing.Optional[str] = None,
+        scheduling: typing.Optional["Scheduling"] = None,
     ):
         """Create RuntimeClassSpec instance."""
         super(RuntimeClassSpec, self).__init__(
@@ -391,10 +391,10 @@ class RuntimeClassSpec(_kuber_definitions.Definition):
         """
         Overhead represents the resource overhead associated with
         running a pod for a given RuntimeClass. For more details,
-        see https://git.k8s.io/enhancements/keps/sig-
-        node/20190226-pod-overhead.md This field is alpha-level as
-        of Kubernetes v1.15, and is only honored by servers that
-        enable the PodOverhead feature.
+        see https://git.k8s.io/enhancements/keps/sig-node/688-pod-
+        overhead/README.md This field is beta-level as of Kubernetes
+        v1.18, and is only honored by servers that enable the
+        PodOverhead feature.
         """
         return typing.cast(
             "Overhead",
@@ -406,10 +406,10 @@ class RuntimeClassSpec(_kuber_definitions.Definition):
         """
         Overhead represents the resource overhead associated with
         running a pod for a given RuntimeClass. For more details,
-        see https://git.k8s.io/enhancements/keps/sig-
-        node/20190226-pod-overhead.md This field is alpha-level as
-        of Kubernetes v1.15, and is only honored by servers that
-        enable the PodOverhead feature.
+        see https://git.k8s.io/enhancements/keps/sig-node/688-pod-
+        overhead/README.md This field is beta-level as of Kubernetes
+        v1.18, and is only honored by servers that enable the
+        PodOverhead feature.
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -496,8 +496,8 @@ class Scheduling(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        node_selector: dict = None,
-        tolerations: typing.List["Toleration"] = None,
+        node_selector: typing.Optional[dict] = None,
+        tolerations: typing.Optional[typing.List["Toleration"]] = None,
     ):
         """Create Scheduling instance."""
         super(Scheduling, self).__init__(api_version="node/v1alpha1", kind="Scheduling")
