@@ -6,12 +6,12 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_18.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_18.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_18.core_v1 import PersistentVolumeSpec  # noqa: F401
-from kuber.v1_18.meta_v1 import Status  # noqa: F401
-from kuber.v1_18.meta_v1 import StatusDetails  # noqa: F401
-from kuber.v1_18.core_v1 import TopologySelectorTerm  # noqa: F401
+from kuber.v1_23.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_23.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_23.core_v1 import PersistentVolumeSpec  # noqa: F401
+from kuber.v1_23.meta_v1 import Status  # noqa: F401
+from kuber.v1_23.meta_v1 import StatusDetails  # noqa: F401
+from kuber.v1_23.core_v1 import TopologySelectorTerm  # noqa: F401
 
 
 class CSIDriver(_kuber_definitions.Resource):
@@ -26,8 +26,8 @@ class CSIDriver(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        spec: "CSIDriverSpec" = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        spec: typing.Optional["CSIDriverSpec"] = None,
     ):
         """Create CSIDriver instance."""
         super(CSIDriver, self).__init__(api_version="storage/v1", kind="CSIDriver")
@@ -102,7 +102,7 @@ class CSIDriver(_kuber_definitions.Resource):
             )
         self._properties["spec"] = value
 
-    def create_resource(self, namespace: "str" = None):
+    def create_resource(self, namespace: typing.Optional["str"] = None):
         """
         Creates the CSIDriver in the currently
         configured Kubernetes cluster.
@@ -118,7 +118,7 @@ class CSIDriver(_kuber_definitions.Resource):
             api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(self, namespace: "str" = None):
+    def replace_resource(self, namespace: typing.Optional["str"] = None):
         """
         Replaces the CSIDriver in the currently
         configured Kubernetes cluster.
@@ -134,7 +134,7 @@ class CSIDriver(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(self, namespace: "str" = None):
+    def patch_resource(self, namespace: typing.Optional["str"] = None):
         """
         Patches the CSIDriver in the currently
         configured Kubernetes cluster.
@@ -150,11 +150,11 @@ class CSIDriver(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(self, namespace: "str" = None):
+    def get_resource_status(self, namespace: typing.Optional["str"] = None):
         """This resource does not have a status."""
         pass
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the CSIDriver from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -174,7 +174,7 @@ class CSIDriver(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -203,7 +203,7 @@ class CSIDriver(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.StorageV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -227,8 +227,8 @@ class CSIDriverList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["CSIDriver"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["CSIDriver"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create CSIDriverList instance."""
         super(CSIDriverList, self).__init__(
@@ -298,7 +298,7 @@ class CSIDriverList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.StorageV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -322,9 +322,13 @@ class CSIDriverSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        attach_required: bool = None,
-        pod_info_on_mount: bool = None,
-        volume_lifecycle_modes: typing.List[str] = None,
+        attach_required: typing.Optional[bool] = None,
+        fs_group_policy: typing.Optional[str] = None,
+        pod_info_on_mount: typing.Optional[bool] = None,
+        requires_republish: typing.Optional[bool] = None,
+        storage_capacity: typing.Optional[bool] = None,
+        token_requests: typing.Optional[typing.List["TokenRequest"]] = None,
+        volume_lifecycle_modes: typing.Optional[typing.List[str]] = None,
     ):
         """Create CSIDriverSpec instance."""
         super(CSIDriverSpec, self).__init__(
@@ -332,16 +336,28 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         )
         self._properties = {
             "attachRequired": attach_required if attach_required is not None else None,
+            "fsGroupPolicy": fs_group_policy if fs_group_policy is not None else "",
             "podInfoOnMount": pod_info_on_mount
             if pod_info_on_mount is not None
             else None,
+            "requiresRepublish": requires_republish
+            if requires_republish is not None
+            else None,
+            "storageCapacity": storage_capacity
+            if storage_capacity is not None
+            else None,
+            "tokenRequests": token_requests if token_requests is not None else [],
             "volumeLifecycleModes": volume_lifecycle_modes
             if volume_lifecycle_modes is not None
             else [],
         }
         self._types = {
             "attachRequired": (bool, None),
+            "fsGroupPolicy": (str, None),
             "podInfoOnMount": (bool, None),
+            "requiresRepublish": (bool, None),
+            "storageCapacity": (bool, None),
+            "tokenRequests": (list, TokenRequest),
             "volumeLifecycleModes": (list, str),
         }
 
@@ -360,6 +376,8 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         is enabled and the value is specified to false, the attach
         operation will be skipped. Otherwise the attach operation
         will be called.
+
+        This field is immutable.
         """
         return typing.cast(
             bool,
@@ -381,9 +399,48 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         is enabled and the value is specified to false, the attach
         operation will be skipped. Otherwise the attach operation
         will be called.
+
+        This field is immutable.
         """
         self._properties["attachRequired"] = value
 
+    @property
+    def fs_group_policy(self) -> str:
+        """
+        Defines if the underlying volume supports changing ownership
+        and permission of the volume before being mounted. Refer to
+        the specific FSGroupPolicy values for additional details.
+
+        This field is immutable.
+
+        Defaults to ReadWriteOnceWithFSType, which will examine each
+        volume to determine if Kubernetes should modify ownership
+        and permissions of the volume. With the default policy the
+        defined fsGroup will only be applied if a fstype is defined
+        and the volume's access mode contains ReadWriteOnce.
+        """
+        return typing.cast(
+            str,
+            self._properties.get("fsGroupPolicy"),
+        )
+
+    @fs_group_policy.setter
+    def fs_group_policy(self, value: str):
+        """
+        Defines if the underlying volume supports changing ownership
+        and permission of the volume before being mounted. Refer to
+        the specific FSGroupPolicy values for additional details.
+
+        This field is immutable.
+
+        Defaults to ReadWriteOnceWithFSType, which will examine each
+        volume to determine if Kubernetes should modify ownership
+        and permissions of the volume. With the default policy the
+        defined fsGroup will only be applied if a fstype is defined
+        and the volume's access mode contains ReadWriteOnce.
+        """
+        self._properties["fsGroupPolicy"] = value
+
     @property
     def pod_info_on_mount(self) -> bool:
         """
@@ -401,7 +458,7 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         "csi.storage.k8s.io/pod.name": pod.Name
         "csi.storage.k8s.io/pod.namespace": pod.Namespace
         "csi.storage.k8s.io/pod.uid": string(pod.UID)
-        "csi.storage.k8s.io/ephemeral": "true" iff the volume is an
+        "csi.storage.k8s.io/ephemeral": "true" if the volume is an
         ephemeral inline volume
                                         defined by a
         CSIVolumeSource, otherwise "false"
@@ -415,6 +472,8 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         mode when deployed on such a cluster and the deployment
         determines which mode that is, for example via a command
         line parameter of the driver.
+
+        This field is immutable.
         """
         return typing.cast(
             bool,
@@ -438,7 +497,7 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         "csi.storage.k8s.io/pod.name": pod.Name
         "csi.storage.k8s.io/pod.namespace": pod.Namespace
         "csi.storage.k8s.io/pod.uid": string(pod.UID)
-        "csi.storage.k8s.io/ephemeral": "true" iff the volume is an
+        "csi.storage.k8s.io/ephemeral": "true" if the volume is an
         ephemeral inline volume
                                         defined by a
         CSIVolumeSource, otherwise "false"
@@ -452,9 +511,158 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         mode when deployed on such a cluster and the deployment
         determines which mode that is, for example via a command
         line parameter of the driver.
+
+        This field is immutable.
         """
         self._properties["podInfoOnMount"] = value
 
+    @property
+    def requires_republish(self) -> bool:
+        """
+        RequiresRepublish indicates the CSI driver wants
+        `NodePublishVolume` being periodically called to reflect any
+        possible change in the mounted volume. This field defaults
+        to false.
+
+        Note: After a successful initial NodePublishVolume call,
+        subsequent calls to NodePublishVolume should only update the
+        contents of the volume. New mount points will not be seen by
+        a running container.
+        """
+        return typing.cast(
+            bool,
+            self._properties.get("requiresRepublish"),
+        )
+
+    @requires_republish.setter
+    def requires_republish(self, value: bool):
+        """
+        RequiresRepublish indicates the CSI driver wants
+        `NodePublishVolume` being periodically called to reflect any
+        possible change in the mounted volume. This field defaults
+        to false.
+
+        Note: After a successful initial NodePublishVolume call,
+        subsequent calls to NodePublishVolume should only update the
+        contents of the volume. New mount points will not be seen by
+        a running container.
+        """
+        self._properties["requiresRepublish"] = value
+
+    @property
+    def storage_capacity(self) -> bool:
+        """
+        If set to true, storageCapacity indicates that the CSI
+        volume driver wants pod scheduling to consider the storage
+        capacity that the driver deployment will report by creating
+        CSIStorageCapacity objects with capacity information.
+
+        The check can be enabled immediately when deploying a
+        driver. In that case, provisioning new volumes with late
+        binding will pause until the driver deployment has published
+        some suitable CSIStorageCapacity object.
+
+        Alternatively, the driver can be deployed with the field
+        unset or false and it can be flipped later when storage
+        capacity information has been published.
+
+        This field was immutable in Kubernetes <= 1.22 and now is
+        mutable.
+
+        This is a beta field and only available when the
+        CSIStorageCapacity feature is enabled. The default is false.
+        """
+        return typing.cast(
+            bool,
+            self._properties.get("storageCapacity"),
+        )
+
+    @storage_capacity.setter
+    def storage_capacity(self, value: bool):
+        """
+        If set to true, storageCapacity indicates that the CSI
+        volume driver wants pod scheduling to consider the storage
+        capacity that the driver deployment will report by creating
+        CSIStorageCapacity objects with capacity information.
+
+        The check can be enabled immediately when deploying a
+        driver. In that case, provisioning new volumes with late
+        binding will pause until the driver deployment has published
+        some suitable CSIStorageCapacity object.
+
+        Alternatively, the driver can be deployed with the field
+        unset or false and it can be flipped later when storage
+        capacity information has been published.
+
+        This field was immutable in Kubernetes <= 1.22 and now is
+        mutable.
+
+        This is a beta field and only available when the
+        CSIStorageCapacity feature is enabled. The default is false.
+        """
+        self._properties["storageCapacity"] = value
+
+    @property
+    def token_requests(self) -> typing.List["TokenRequest"]:
+        """
+        TokenRequests indicates the CSI driver needs pods' service
+        account tokens it is mounting volume for to do necessary
+        authentication. Kubelet will pass the tokens in
+        VolumeContext in the CSI NodePublishVolume calls. The CSI
+        driver should parse and validate the following
+        VolumeContext: "csi.storage.k8s.io/serviceAccount.tokens": {
+          "<audience>": {
+            "token": <token>,
+            "expirationTimestamp": <expiration timestamp in
+        RFC3339>,
+          },
+          ...
+        }
+
+        Note: Audience in each TokenRequest should be different and
+        at most one token is empty string. To receive a new token
+        after expiry, RequiresRepublish can be used to trigger
+        NodePublishVolume periodically.
+        """
+        return typing.cast(
+            typing.List["TokenRequest"],
+            self._properties.get("tokenRequests"),
+        )
+
+    @token_requests.setter
+    def token_requests(
+        self, value: typing.Union[typing.List["TokenRequest"], typing.List[dict]]
+    ):
+        """
+        TokenRequests indicates the CSI driver needs pods' service
+        account tokens it is mounting volume for to do necessary
+        authentication. Kubelet will pass the tokens in
+        VolumeContext in the CSI NodePublishVolume calls. The CSI
+        driver should parse and validate the following
+        VolumeContext: "csi.storage.k8s.io/serviceAccount.tokens": {
+          "<audience>": {
+            "token": <token>,
+            "expirationTimestamp": <expiration timestamp in
+        RFC3339>,
+          },
+          ...
+        }
+
+        Note: Audience in each TokenRequest should be different and
+        at most one token is empty string. To receive a new token
+        after expiry, RequiresRepublish can be used to trigger
+        NodePublishVolume periodically.
+        """
+        cleaned: typing.List[TokenRequest] = []
+        for item in value:
+            if isinstance(item, dict):
+                item = typing.cast(
+                    TokenRequest,
+                    TokenRequest().from_dict(item),
+                )
+            cleaned.append(typing.cast(TokenRequest, item))
+        self._properties["tokenRequests"] = cleaned
+
     @property
     def volume_lifecycle_modes(self) -> typing.List[str]:
         """
@@ -472,6 +680,8 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         volumes.html A driver can support one or more of these modes
         and more modes may be added in the future. This field is
         beta.
+
+        This field is immutable.
         """
         return typing.cast(
             typing.List[str],
@@ -495,6 +705,8 @@ class CSIDriverSpec(_kuber_definitions.Definition):
         volumes.html A driver can support one or more of these modes
         and more modes may be added in the future. This field is
         beta.
+
+        This field is immutable.
         """
         self._properties["volumeLifecycleModes"] = value
 
@@ -521,8 +733,8 @@ class CSINode(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        spec: "CSINodeSpec" = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        spec: typing.Optional["CSINodeSpec"] = None,
     ):
         """Create CSINode instance."""
         super(CSINode, self).__init__(api_version="storage/v1", kind="CSINode")
@@ -581,7 +793,7 @@ class CSINode(_kuber_definitions.Resource):
             )
         self._properties["spec"] = value
 
-    def create_resource(self, namespace: "str" = None):
+    def create_resource(self, namespace: typing.Optional["str"] = None):
         """
         Creates the CSINode in the currently
         configured Kubernetes cluster.
@@ -597,7 +809,7 @@ class CSINode(_kuber_definitions.Resource):
             api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(self, namespace: "str" = None):
+    def replace_resource(self, namespace: typing.Optional["str"] = None):
         """
         Replaces the CSINode in the currently
         configured Kubernetes cluster.
@@ -613,7 +825,7 @@ class CSINode(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(self, namespace: "str" = None):
+    def patch_resource(self, namespace: typing.Optional["str"] = None):
         """
         Patches the CSINode in the currently
         configured Kubernetes cluster.
@@ -629,11 +841,11 @@ class CSINode(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(self, namespace: "str" = None):
+    def get_resource_status(self, namespace: typing.Optional["str"] = None):
         """This resource does not have a status."""
         pass
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the CSINode from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -653,7 +865,7 @@ class CSINode(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -682,7 +894,7 @@ class CSINode(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.StorageV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -707,10 +919,10 @@ class CSINodeDriver(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        allocatable: "VolumeNodeResources" = None,
-        name: str = None,
-        node_id: str = None,
-        topology_keys: typing.List[str] = None,
+        allocatable: typing.Optional["VolumeNodeResources"] = None,
+        name: typing.Optional[str] = None,
+        node_id: typing.Optional[str] = None,
+        topology_keys: typing.Optional[typing.List[str]] = None,
     ):
         """Create CSINodeDriver instance."""
         super(CSINodeDriver, self).__init__(
@@ -864,8 +1076,8 @@ class CSINodeList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["CSINode"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["CSINode"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create CSINodeList instance."""
         super(CSINodeList, self).__init__(api_version="storage/v1", kind="CSINodeList")
@@ -933,7 +1145,7 @@ class CSINodeList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.StorageV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -958,7 +1170,7 @@ class CSINodeSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        drivers: typing.List["CSINodeDriver"] = None,
+        drivers: typing.Optional[typing.List["CSINodeDriver"]] = None,
     ):
         """Create CSINodeSpec instance."""
         super(CSINodeSpec, self).__init__(api_version="storage/v1", kind="CSINodeSpec")
@@ -1018,14 +1230,14 @@ class StorageClass(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        allow_volume_expansion: bool = None,
-        allowed_topologies: typing.List["TopologySelectorTerm"] = None,
-        metadata: "ObjectMeta" = None,
-        mount_options: typing.List[str] = None,
-        parameters: dict = None,
-        provisioner: str = None,
-        reclaim_policy: str = None,
-        volume_binding_mode: str = None,
+        allow_volume_expansion: typing.Optional[bool] = None,
+        allowed_topologies: typing.Optional[typing.List["TopologySelectorTerm"]] = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        mount_options: typing.Optional[typing.List[str]] = None,
+        parameters: typing.Optional[dict] = None,
+        provisioner: typing.Optional[str] = None,
+        reclaim_policy: typing.Optional[str] = None,
+        volume_binding_mode: typing.Optional[str] = None,
     ):
         """Create StorageClass instance."""
         super(StorageClass, self).__init__(
@@ -1246,7 +1458,7 @@ class StorageClass(_kuber_definitions.Resource):
         """
         self._properties["volumeBindingMode"] = value
 
-    def create_resource(self, namespace: "str" = None):
+    def create_resource(self, namespace: typing.Optional["str"] = None):
         """
         Creates the StorageClass in the currently
         configured Kubernetes cluster.
@@ -1262,7 +1474,7 @@ class StorageClass(_kuber_definitions.Resource):
             api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(self, namespace: "str" = None):
+    def replace_resource(self, namespace: typing.Optional["str"] = None):
         """
         Replaces the StorageClass in the currently
         configured Kubernetes cluster.
@@ -1278,7 +1490,7 @@ class StorageClass(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(self, namespace: "str" = None):
+    def patch_resource(self, namespace: typing.Optional["str"] = None):
         """
         Patches the StorageClass in the currently
         configured Kubernetes cluster.
@@ -1294,11 +1506,11 @@ class StorageClass(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(self, namespace: "str" = None):
+    def get_resource_status(self, namespace: typing.Optional["str"] = None):
         """This resource does not have a status."""
         pass
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the StorageClass from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -1318,7 +1530,7 @@ class StorageClass(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -1347,7 +1559,7 @@ class StorageClass(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.StorageV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -1371,8 +1583,8 @@ class StorageClassList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["StorageClass"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["StorageClass"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create StorageClassList instance."""
         super(StorageClassList, self).__init__(
@@ -1444,7 +1656,7 @@ class StorageClassList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.StorageV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -1461,6 +1673,80 @@ class StorageClassList(_kuber_definitions.Collection):
         return False
 
 
+class TokenRequest(_kuber_definitions.Definition):
+    """
+    TokenRequest contains parameters of a service account token.
+    """
+
+    def __init__(
+        self,
+        audience: typing.Optional[str] = None,
+        expiration_seconds: typing.Optional[int] = None,
+    ):
+        """Create TokenRequest instance."""
+        super(TokenRequest, self).__init__(
+            api_version="storage/v1", kind="TokenRequest"
+        )
+        self._properties = {
+            "audience": audience if audience is not None else "",
+            "expirationSeconds": expiration_seconds
+            if expiration_seconds is not None
+            else None,
+        }
+        self._types = {
+            "audience": (str, None),
+            "expirationSeconds": (int, None),
+        }
+
+    @property
+    def audience(self) -> str:
+        """
+        Audience is the intended audience of the token in
+        "TokenRequestSpec". It will default to the audiences of kube
+        apiserver.
+        """
+        return typing.cast(
+            str,
+            self._properties.get("audience"),
+        )
+
+    @audience.setter
+    def audience(self, value: str):
+        """
+        Audience is the intended audience of the token in
+        "TokenRequestSpec". It will default to the audiences of kube
+        apiserver.
+        """
+        self._properties["audience"] = value
+
+    @property
+    def expiration_seconds(self) -> int:
+        """
+        ExpirationSeconds is the duration of validity of the token
+        in "TokenRequestSpec". It has the same default value of
+        "ExpirationSeconds" in "TokenRequestSpec".
+        """
+        return typing.cast(
+            int,
+            self._properties.get("expirationSeconds"),
+        )
+
+    @expiration_seconds.setter
+    def expiration_seconds(self, value: int):
+        """
+        ExpirationSeconds is the duration of validity of the token
+        in "TokenRequestSpec". It has the same default value of
+        "ExpirationSeconds" in "TokenRequestSpec".
+        """
+        self._properties["expirationSeconds"] = value
+
+    def __enter__(self) -> "TokenRequest":
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        return False
+
+
 class VolumeAttachment(_kuber_definitions.Resource):
     """
     VolumeAttachment captures the intent to attach or detach the
@@ -1471,9 +1757,9 @@ class VolumeAttachment(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        spec: "VolumeAttachmentSpec" = None,
-        status: "VolumeAttachmentStatus" = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        spec: typing.Optional["VolumeAttachmentSpec"] = None,
+        status: typing.Optional["VolumeAttachmentStatus"] = None,
     ):
         """Create VolumeAttachment instance."""
         super(VolumeAttachment, self).__init__(
@@ -1568,7 +1854,9 @@ class VolumeAttachment(_kuber_definitions.Resource):
             )
         self._properties["status"] = value
 
-    def create_resource(self, namespace: "str" = None) -> "VolumeAttachmentStatus":
+    def create_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "VolumeAttachmentStatus":
         """
         Creates the VolumeAttachment in the currently
         configured Kubernetes cluster and returns the status information
@@ -1590,7 +1878,9 @@ class VolumeAttachment(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def replace_resource(self, namespace: "str" = None) -> "VolumeAttachmentStatus":
+    def replace_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "VolumeAttachmentStatus":
         """
         Replaces the VolumeAttachment in the currently
         configured Kubernetes cluster and returns the status information
@@ -1612,7 +1902,9 @@ class VolumeAttachment(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def patch_resource(self, namespace: "str" = None) -> "VolumeAttachmentStatus":
+    def patch_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "VolumeAttachmentStatus":
         """
         Patches the VolumeAttachment in the currently
         configured Kubernetes cluster and returns the status information
@@ -1634,7 +1926,9 @@ class VolumeAttachment(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def get_resource_status(self, namespace: "str" = None) -> "VolumeAttachmentStatus":
+    def get_resource_status(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "VolumeAttachmentStatus":
         """
         Returns status information about the given resource within the cluster.
         """
@@ -1657,7 +1951,7 @@ class VolumeAttachment(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the VolumeAttachment from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -1677,7 +1971,7 @@ class VolumeAttachment(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -1706,7 +2000,7 @@ class VolumeAttachment(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.StorageV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -1731,8 +2025,8 @@ class VolumeAttachmentList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["VolumeAttachment"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["VolumeAttachment"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create VolumeAttachmentList instance."""
         super(VolumeAttachmentList, self).__init__(
@@ -1804,7 +2098,7 @@ class VolumeAttachmentList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.StorageV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -1831,8 +2125,8 @@ class VolumeAttachmentSource(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        inline_volume_spec: "PersistentVolumeSpec" = None,
-        persistent_volume_name: str = None,
+        inline_volume_spec: typing.Optional["PersistentVolumeSpec"] = None,
+        persistent_volume_name: typing.Optional[str] = None,
     ):
         """Create VolumeAttachmentSource instance."""
         super(VolumeAttachmentSource, self).__init__(
@@ -1859,7 +2153,7 @@ class VolumeAttachmentSource(_kuber_definitions.Definition):
         VolumeSource. This field is populated only for the
         CSIMigration feature. It contains translated fields from a
         pod's inline VolumeSource to a PersistentVolumeSpec. This
-        field is alpha-level and is only honored by servers that
+        field is beta-level and is only honored by servers that
         enabled the CSIMigration feature.
         """
         return typing.cast(
@@ -1875,7 +2169,7 @@ class VolumeAttachmentSource(_kuber_definitions.Definition):
         VolumeSource. This field is populated only for the
         CSIMigration feature. It contains translated fields from a
         pod's inline VolumeSource to a PersistentVolumeSpec. This
-        field is alpha-level and is only honored by servers that
+        field is beta-level and is only honored by servers that
         enabled the CSIMigration feature.
         """
         if isinstance(value, dict):
@@ -1917,9 +2211,9 @@ class VolumeAttachmentSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        attacher: str = None,
-        node_name: str = None,
-        source: "VolumeAttachmentSource" = None,
+        attacher: typing.Optional[str] = None,
+        node_name: typing.Optional[str] = None,
+        source: typing.Optional["VolumeAttachmentSource"] = None,
     ):
         """Create VolumeAttachmentSpec instance."""
         super(VolumeAttachmentSpec, self).__init__(
@@ -2011,10 +2305,10 @@ class VolumeAttachmentStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        attach_error: "VolumeError" = None,
-        attached: bool = None,
-        attachment_metadata: dict = None,
-        detach_error: "VolumeError" = None,
+        attach_error: typing.Optional["VolumeError"] = None,
+        attached: typing.Optional[bool] = None,
+        attachment_metadata: typing.Optional[dict] = None,
+        detach_error: typing.Optional["VolumeError"] = None,
     ):
         """Create VolumeAttachmentStatus instance."""
         super(VolumeAttachmentStatus, self).__init__(
@@ -2148,8 +2442,8 @@ class VolumeError(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        message: str = None,
-        time: str = None,
+        message: typing.Optional[str] = None,
+        time: typing.Optional[str] = None,
     ):
         """Create VolumeError instance."""
         super(VolumeError, self).__init__(api_version="storage/v1", kind="VolumeError")
@@ -2219,7 +2513,7 @@ class VolumeNodeResources(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        count: int = None,
+        count: typing.Optional[int] = None,
     ):
         """Create VolumeNodeResources instance."""
         super(VolumeNodeResources, self).__init__(
