@@ -6,22 +6,22 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_18.core_v1 import Container  # noqa: F401
-from kuber.v1_18.core_v1 import ContainerPort  # noqa: F401
-from kuber.v1_18.core_v1 import EnvFromSource  # noqa: F401
-from kuber.v1_18.core_v1 import EnvVar  # noqa: F401
-from kuber.v1_18.batch_v1 import JobSpec  # noqa: F401
-from kuber.v1_18.core_v1 import Lifecycle  # noqa: F401
-from kuber.v1_18.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_18.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_18.core_v1 import ObjectReference  # noqa: F401
-from kuber.v1_18.core_v1 import Probe  # noqa: F401
-from kuber.v1_18.core_v1 import ResourceRequirements  # noqa: F401
-from kuber.v1_18.core_v1 import SecurityContext  # noqa: F401
-from kuber.v1_18.meta_v1 import Status  # noqa: F401
-from kuber.v1_18.meta_v1 import StatusDetails  # noqa: F401
-from kuber.v1_18.core_v1 import VolumeDevice  # noqa: F401
-from kuber.v1_18.core_v1 import VolumeMount  # noqa: F401
+from kuber.v1_24.core_v1 import Container  # noqa: F401
+from kuber.v1_24.core_v1 import ContainerPort  # noqa: F401
+from kuber.v1_24.core_v1 import EnvFromSource  # noqa: F401
+from kuber.v1_24.core_v1 import EnvVar  # noqa: F401
+from kuber.v1_24.batch_v1 import JobSpec  # noqa: F401
+from kuber.v1_24.core_v1 import Lifecycle  # noqa: F401
+from kuber.v1_24.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_24.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_24.core_v1 import ObjectReference  # noqa: F401
+from kuber.v1_24.core_v1 import Probe  # noqa: F401
+from kuber.v1_24.core_v1 import ResourceRequirements  # noqa: F401
+from kuber.v1_24.core_v1 import SecurityContext  # noqa: F401
+from kuber.v1_24.meta_v1 import Status  # noqa: F401
+from kuber.v1_24.meta_v1 import StatusDetails  # noqa: F401
+from kuber.v1_24.core_v1 import VolumeDevice  # noqa: F401
+from kuber.v1_24.core_v1 import VolumeMount  # noqa: F401
 
 
 class CronJob(_kuber_definitions.Resource):
@@ -31,9 +31,9 @@ class CronJob(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        spec: "CronJobSpec" = None,
-        status: "CronJobStatus" = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        spec: typing.Optional["CronJobSpec"] = None,
+        status: typing.Optional["CronJobStatus"] = None,
     ):
         """Create CronJob instance."""
         super(CronJob, self).__init__(api_version="batch/v1beta1", kind="CronJob")
@@ -279,7 +279,9 @@ class CronJob(_kuber_definitions.Resource):
         """
         return self.spec.job_template.spec.template.spec.containers
 
-    def create_resource(self, namespace: "str" = None) -> "CronJobStatus":
+    def create_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "CronJobStatus":
         """
         Creates the CronJob in the currently
         configured Kubernetes cluster and returns the status information
@@ -301,7 +303,9 @@ class CronJob(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def replace_resource(self, namespace: "str" = None) -> "CronJobStatus":
+    def replace_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "CronJobStatus":
         """
         Replaces the CronJob in the currently
         configured Kubernetes cluster and returns the status information
@@ -323,7 +327,9 @@ class CronJob(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def patch_resource(self, namespace: "str" = None) -> "CronJobStatus":
+    def patch_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "CronJobStatus":
         """
         Patches the CronJob in the currently
         configured Kubernetes cluster and returns the status information
@@ -345,7 +351,9 @@ class CronJob(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def get_resource_status(self, namespace: "str" = None) -> "CronJobStatus":
+    def get_resource_status(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "CronJobStatus":
         """
         Returns status information about the given resource within the cluster.
         """
@@ -368,7 +376,7 @@ class CronJob(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the CronJob from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -388,7 +396,7 @@ class CronJob(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -417,7 +425,7 @@ class CronJob(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.BatchV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -441,8 +449,8 @@ class CronJobList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["CronJob"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["CronJob"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create CronJobList instance."""
         super(CronJobList, self).__init__(
@@ -512,7 +520,7 @@ class CronJobList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.BatchV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -537,13 +545,14 @@ class CronJobSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        concurrency_policy: str = None,
-        failed_jobs_history_limit: int = None,
-        job_template: "JobTemplateSpec" = None,
-        schedule: str = None,
-        starting_deadline_seconds: int = None,
-        successful_jobs_history_limit: int = None,
-        suspend: bool = None,
+        concurrency_policy: typing.Optional[str] = None,
+        failed_jobs_history_limit: typing.Optional[int] = None,
+        job_template: typing.Optional["JobTemplateSpec"] = None,
+        schedule: typing.Optional[str] = None,
+        starting_deadline_seconds: typing.Optional[int] = None,
+        successful_jobs_history_limit: typing.Optional[int] = None,
+        suspend: typing.Optional[bool] = None,
+        time_zone: typing.Optional[str] = None,
     ):
         """Create CronJobSpec instance."""
         super(CronJobSpec, self).__init__(
@@ -567,6 +576,7 @@ class CronJobSpec(_kuber_definitions.Definition):
             if successful_jobs_history_limit is not None
             else None,
             "suspend": suspend if suspend is not None else None,
+            "timeZone": time_zone if time_zone is not None else "",
         }
         self._types = {
             "concurrencyPolicy": (str, None),
@@ -576,6 +586,7 @@ class CronJobSpec(_kuber_definitions.Definition):
             "startingDeadlineSeconds": (int, None),
             "successfulJobsHistoryLimit": (int, None),
             "suspend": (bool, None),
+            "timeZone": (str, None),
         }
 
     @property
@@ -730,6 +741,31 @@ class CronJobSpec(_kuber_definitions.Definition):
         """
         self._properties["suspend"] = value
 
+    @property
+    def time_zone(self) -> str:
+        """
+        The time zone for the given schedule, see https://en.wikiped
+        ia.org/wiki/List_of_tz_database_time_zones. If not
+        specified, this will rely on the time zone of the kube-
+        controller-manager process. ALPHA: This field is in alpha
+        and must be enabled via the `CronJobTimeZone` feature gate.
+        """
+        return typing.cast(
+            str,
+            self._properties.get("timeZone"),
+        )
+
+    @time_zone.setter
+    def time_zone(self, value: str):
+        """
+        The time zone for the given schedule, see https://en.wikiped
+        ia.org/wiki/List_of_tz_database_time_zones. If not
+        specified, this will rely on the time zone of the kube-
+        controller-manager process. ALPHA: This field is in alpha
+        and must be enabled via the `CronJobTimeZone` feature gate.
+        """
+        self._properties["timeZone"] = value
+
     def append_container(
         self,
         args: typing.Union[
@@ -893,8 +929,9 @@ class CronJobStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        active: typing.List["ObjectReference"] = None,
-        last_schedule_time: str = None,
+        active: typing.Optional[typing.List["ObjectReference"]] = None,
+        last_schedule_time: typing.Optional[str] = None,
+        last_successful_time: typing.Optional[str] = None,
     ):
         """Create CronJobStatus instance."""
         super(CronJobStatus, self).__init__(
@@ -905,10 +942,14 @@ class CronJobStatus(_kuber_definitions.Definition):
             "lastScheduleTime": last_schedule_time
             if last_schedule_time is not None
             else None,
+            "lastSuccessfulTime": last_successful_time
+            if last_successful_time is not None
+            else None,
         }
         self._types = {
             "active": (list, ObjectReference),
             "lastScheduleTime": (str, None),
+            "lastSuccessfulTime": (str, None),
         }
 
     @property
@@ -963,6 +1004,31 @@ class CronJobStatus(_kuber_definitions.Definition):
             value = value.strftime("%Y-%m-%dT00:00:00Z")
         self._properties["lastScheduleTime"] = value
 
+    @property
+    def last_successful_time(self) -> str:
+        """
+        Information when was the last time the job successfully
+        completed.
+        """
+        return typing.cast(
+            str,
+            self._properties.get("lastSuccessfulTime"),
+        )
+
+    @last_successful_time.setter
+    def last_successful_time(
+        self, value: typing.Union[str, _datetime.datetime, _datetime.date]
+    ):
+        """
+        Information when was the last time the job successfully
+        completed.
+        """
+        if isinstance(value, _datetime.datetime):
+            value = value.strftime("%Y-%m-%dT%H:%M:%SZ")
+        elif isinstance(value, _datetime.date):
+            value = value.strftime("%Y-%m-%dT00:00:00Z")
+        self._properties["lastSuccessfulTime"] = value
+
     def __enter__(self) -> "CronJobStatus":
         return self
 
@@ -978,8 +1044,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        spec: "JobSpec" = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        spec: typing.Optional["JobSpec"] = None,
     ):
         """Create JobTemplateSpec instance."""
         super(JobTemplateSpec, self).__init__(
