@@ -6,36 +6,42 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_19.core_v1 import EventSource  # noqa: F401
-from kuber.v1_19.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_19.meta_v1 import MicroTime  # noqa: F401
-from kuber.v1_19.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_19.core_v1 import ObjectReference  # noqa: F401
+from kuber.v1_24.core_v1 import EventSource  # noqa: F401
+from kuber.v1_24.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_24.meta_v1 import MicroTime  # noqa: F401
+from kuber.v1_24.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_24.core_v1 import ObjectReference  # noqa: F401
 
 
 class Event(_kuber_definitions.Resource):
     """
     Event is a report of an event somewhere in the cluster. It
-    generally denotes some state change in the system.
+    generally denotes some state change in the system. Events
+    have a limited retention time and triggers and messages may
+    evolve with time.  Event consumers should not rely on the
+    timing of an event with a given Reason reflecting a
+    consistent underlying trigger, or the continued existence of
+    events with that Reason.  Events should be treated as
+    informative, best-effort, supplemental data.
     """
 
     def __init__(
         self,
-        action: str = None,
-        deprecated_count: int = None,
-        deprecated_first_timestamp: str = None,
-        deprecated_last_timestamp: str = None,
-        deprecated_source: "EventSource" = None,
-        event_time: "MicroTime" = None,
-        metadata: "ObjectMeta" = None,
-        note: str = None,
-        reason: str = None,
-        regarding: "ObjectReference" = None,
-        related: "ObjectReference" = None,
-        reporting_controller: str = None,
-        reporting_instance: str = None,
-        series: "EventSeries" = None,
-        type_: str = None,
+        action: typing.Optional[str] = None,
+        deprecated_count: typing.Optional[int] = None,
+        deprecated_first_timestamp: typing.Optional[str] = None,
+        deprecated_last_timestamp: typing.Optional[str] = None,
+        deprecated_source: typing.Optional["EventSource"] = None,
+        event_time: typing.Optional["MicroTime"] = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        note: typing.Optional[str] = None,
+        reason: typing.Optional[str] = None,
+        regarding: typing.Optional["ObjectReference"] = None,
+        related: typing.Optional["ObjectReference"] = None,
+        reporting_controller: typing.Optional[str] = None,
+        reporting_instance: typing.Optional[str] = None,
+        series: typing.Optional["EventSeries"] = None,
+        type_: typing.Optional[str] = None,
     ):
         """Create Event instance."""
         super(Event, self).__init__(api_version="events/v1beta1", kind="Event")
@@ -228,7 +234,11 @@ class Event(_kuber_definitions.Resource):
 
     @property
     def metadata(self) -> "ObjectMeta":
-        """ """
+        """
+        Standard object's metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         return typing.cast(
             "ObjectMeta",
             self._properties.get("metadata"),
@@ -236,7 +246,11 @@ class Event(_kuber_definitions.Resource):
 
     @metadata.setter
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
-        """ """
+        """
+        Standard object's metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         if isinstance(value, dict):
             value = typing.cast(
                 ObjectMeta,
@@ -425,7 +439,7 @@ class Event(_kuber_definitions.Resource):
         """
         self._properties["type"] = value
 
-    def create_resource(self, namespace: "str" = None):
+    def create_resource(self, namespace: typing.Optional["str"] = None):
         """
         Creates the Event in the currently
         configured Kubernetes cluster.
@@ -441,7 +455,7 @@ class Event(_kuber_definitions.Resource):
             api_args={"body": self.to_dict()},
         )
 
-    def replace_resource(self, namespace: "str" = None):
+    def replace_resource(self, namespace: typing.Optional["str"] = None):
         """
         Replaces the Event in the currently
         configured Kubernetes cluster.
@@ -457,7 +471,7 @@ class Event(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def patch_resource(self, namespace: "str" = None):
+    def patch_resource(self, namespace: typing.Optional["str"] = None):
         """
         Patches the Event in the currently
         configured Kubernetes cluster.
@@ -473,11 +487,11 @@ class Event(_kuber_definitions.Resource):
             api_args={"body": self.to_dict(), "name": self.metadata.name},
         )
 
-    def get_resource_status(self, namespace: "str" = None):
+    def get_resource_status(self, namespace: typing.Optional["str"] = None):
         """This resource does not have a status."""
         pass
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the Event from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -497,7 +511,7 @@ class Event(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -526,7 +540,7 @@ class Event(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.EventsV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -550,8 +564,8 @@ class EventList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["Event"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["Event"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create EventList instance."""
         super(EventList, self).__init__(api_version="events/v1beta1", kind="EventList")
@@ -619,7 +633,7 @@ class EventList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.EventsV1beta1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -644,8 +658,8 @@ class EventSeries(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        count: int = None,
-        last_observed_time: "MicroTime" = None,
+        count: typing.Optional[int] = None,
+        last_observed_time: typing.Optional["MicroTime"] = None,
     ):
         """Create EventSeries instance."""
         super(EventSeries, self).__init__(
