@@ -5,10 +5,10 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_20.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_20.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_20.meta_v1 import Status  # noqa: F401
-from kuber.v1_20.meta_v1 import StatusDetails  # noqa: F401
+from kuber.v1_25.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_25.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_25.meta_v1 import Status  # noqa: F401
+from kuber.v1_25.meta_v1 import StatusDetails  # noqa: F401
 
 
 class LocalSubjectAccessReview(_kuber_definitions.Resource):
@@ -21,9 +21,9 @@ class LocalSubjectAccessReview(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        spec: "SubjectAccessReviewSpec" = None,
-        status: "SubjectAccessReviewStatus" = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        spec: typing.Optional["SubjectAccessReviewSpec"] = None,
+        status: typing.Optional["SubjectAccessReviewStatus"] = None,
     ):
         """Create LocalSubjectAccessReview instance."""
         super(LocalSubjectAccessReview, self).__init__(
@@ -44,7 +44,11 @@ class LocalSubjectAccessReview(_kuber_definitions.Resource):
 
     @property
     def metadata(self) -> "ObjectMeta":
-        """ """
+        """
+        Standard list metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         return typing.cast(
             "ObjectMeta",
             self._properties.get("metadata"),
@@ -52,7 +56,11 @@ class LocalSubjectAccessReview(_kuber_definitions.Resource):
 
     @metadata.setter
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
-        """ """
+        """
+        Standard list metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         if isinstance(value, dict):
             value = typing.cast(
                 ObjectMeta,
@@ -110,7 +118,9 @@ class LocalSubjectAccessReview(_kuber_definitions.Resource):
             )
         self._properties["status"] = value
 
-    def create_resource(self, namespace: "str" = None) -> "SubjectAccessReviewStatus":
+    def create_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "SubjectAccessReviewStatus":
         """
         Creates the LocalSubjectAccessReview in the currently
         configured Kubernetes cluster and returns the status information
@@ -135,7 +145,9 @@ class LocalSubjectAccessReview(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def replace_resource(self, namespace: "str" = None) -> "SubjectAccessReviewStatus":
+    def replace_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "SubjectAccessReviewStatus":
         """
         Replaces the LocalSubjectAccessReview in the currently
         configured Kubernetes cluster and returns the status information
@@ -160,7 +172,9 @@ class LocalSubjectAccessReview(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def patch_resource(self, namespace: "str" = None) -> "SubjectAccessReviewStatus":
+    def patch_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "SubjectAccessReviewStatus":
         """
         Patches the LocalSubjectAccessReview in the currently
         configured Kubernetes cluster and returns the status information
@@ -186,7 +200,7 @@ class LocalSubjectAccessReview(_kuber_definitions.Resource):
         return output
 
     def get_resource_status(
-        self, namespace: "str" = None
+        self, namespace: typing.Optional["str"] = None
     ) -> "SubjectAccessReviewStatus":
         """
         Returns status information about the given resource within the cluster.
@@ -210,7 +224,7 @@ class LocalSubjectAccessReview(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the LocalSubjectAccessReview from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -230,7 +244,7 @@ class LocalSubjectAccessReview(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -259,7 +273,7 @@ class LocalSubjectAccessReview(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.AuthorizationV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -285,8 +299,8 @@ class NonResourceAttributes(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        path: str = None,
-        verb: str = None,
+        path: typing.Optional[str] = None,
+        verb: typing.Optional[str] = None,
     ):
         """Create NonResourceAttributes instance."""
         super(NonResourceAttributes, self).__init__(
@@ -350,8 +364,8 @@ class NonResourceRule(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        non_resource_urls: typing.List[str] = None,
-        verbs: typing.List[str] = None,
+        non_resource_urls: typing.Optional[typing.List[str]] = None,
+        verbs: typing.Optional[typing.List[str]] = None,
     ):
         """Create NonResourceRule instance."""
         super(NonResourceRule, self).__init__(
@@ -425,13 +439,13 @@ class ResourceAttributes(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        group: str = None,
-        name: str = None,
-        namespace: str = None,
-        resource: str = None,
-        subresource: str = None,
-        verb: str = None,
-        version: str = None,
+        group: typing.Optional[str] = None,
+        name: typing.Optional[str] = None,
+        namespace: typing.Optional[str] = None,
+        resource: typing.Optional[str] = None,
+        subresource: typing.Optional[str] = None,
+        verb: typing.Optional[str] = None,
+        version: typing.Optional[str] = None,
     ):
         """Create ResourceAttributes instance."""
         super(ResourceAttributes, self).__init__(
@@ -612,10 +626,10 @@ class ResourceRule(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        api_groups: typing.List[str] = None,
-        resource_names: typing.List[str] = None,
-        resources: typing.List[str] = None,
-        verbs: typing.List[str] = None,
+        api_groups: typing.Optional[typing.List[str]] = None,
+        resource_names: typing.Optional[typing.List[str]] = None,
+        resources: typing.Optional[typing.List[str]] = None,
+        verbs: typing.Optional[typing.List[str]] = None,
     ):
         """Create ResourceRule instance."""
         super(ResourceRule, self).__init__(
@@ -738,9 +752,9 @@ class SelfSubjectAccessReview(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        spec: "SelfSubjectAccessReviewSpec" = None,
-        status: "SubjectAccessReviewStatus" = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        spec: typing.Optional["SelfSubjectAccessReviewSpec"] = None,
+        status: typing.Optional["SubjectAccessReviewStatus"] = None,
     ):
         """Create SelfSubjectAccessReview instance."""
         super(SelfSubjectAccessReview, self).__init__(
@@ -761,7 +775,11 @@ class SelfSubjectAccessReview(_kuber_definitions.Resource):
 
     @property
     def metadata(self) -> "ObjectMeta":
-        """ """
+        """
+        Standard list metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         return typing.cast(
             "ObjectMeta",
             self._properties.get("metadata"),
@@ -769,7 +787,11 @@ class SelfSubjectAccessReview(_kuber_definitions.Resource):
 
     @metadata.setter
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
-        """ """
+        """
+        Standard list metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         if isinstance(value, dict):
             value = typing.cast(
                 ObjectMeta,
@@ -825,7 +847,9 @@ class SelfSubjectAccessReview(_kuber_definitions.Resource):
             )
         self._properties["status"] = value
 
-    def create_resource(self, namespace: "str" = None) -> "SubjectAccessReviewStatus":
+    def create_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "SubjectAccessReviewStatus":
         """
         Creates the SelfSubjectAccessReview in the currently
         configured Kubernetes cluster and returns the status information
@@ -850,7 +874,9 @@ class SelfSubjectAccessReview(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def replace_resource(self, namespace: "str" = None) -> "SubjectAccessReviewStatus":
+    def replace_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "SubjectAccessReviewStatus":
         """
         Replaces the SelfSubjectAccessReview in the currently
         configured Kubernetes cluster and returns the status information
@@ -875,7 +901,9 @@ class SelfSubjectAccessReview(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def patch_resource(self, namespace: "str" = None) -> "SubjectAccessReviewStatus":
+    def patch_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "SubjectAccessReviewStatus":
         """
         Patches the SelfSubjectAccessReview in the currently
         configured Kubernetes cluster and returns the status information
@@ -901,7 +929,7 @@ class SelfSubjectAccessReview(_kuber_definitions.Resource):
         return output
 
     def get_resource_status(
-        self, namespace: "str" = None
+        self, namespace: typing.Optional["str"] = None
     ) -> "SubjectAccessReviewStatus":
         """
         Returns status information about the given resource within the cluster.
@@ -925,7 +953,7 @@ class SelfSubjectAccessReview(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the SelfSubjectAccessReview from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -945,7 +973,7 @@ class SelfSubjectAccessReview(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -974,7 +1002,7 @@ class SelfSubjectAccessReview(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.AuthorizationV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -1000,8 +1028,8 @@ class SelfSubjectAccessReviewSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        non_resource_attributes: "NonResourceAttributes" = None,
-        resource_attributes: "ResourceAttributes" = None,
+        non_resource_attributes: typing.Optional["NonResourceAttributes"] = None,
+        resource_attributes: typing.Optional["ResourceAttributes"] = None,
     ):
         """Create SelfSubjectAccessReviewSpec instance."""
         super(SelfSubjectAccessReviewSpec, self).__init__(
@@ -1095,9 +1123,9 @@ class SelfSubjectRulesReview(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        spec: "SelfSubjectRulesReviewSpec" = None,
-        status: "SubjectRulesReviewStatus" = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        spec: typing.Optional["SelfSubjectRulesReviewSpec"] = None,
+        status: typing.Optional["SubjectRulesReviewStatus"] = None,
     ):
         """Create SelfSubjectRulesReview instance."""
         super(SelfSubjectRulesReview, self).__init__(
@@ -1118,7 +1146,11 @@ class SelfSubjectRulesReview(_kuber_definitions.Resource):
 
     @property
     def metadata(self) -> "ObjectMeta":
-        """ """
+        """
+        Standard list metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         return typing.cast(
             "ObjectMeta",
             self._properties.get("metadata"),
@@ -1126,7 +1158,11 @@ class SelfSubjectRulesReview(_kuber_definitions.Resource):
 
     @metadata.setter
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
-        """ """
+        """
+        Standard list metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         if isinstance(value, dict):
             value = typing.cast(
                 ObjectMeta,
@@ -1180,7 +1216,9 @@ class SelfSubjectRulesReview(_kuber_definitions.Resource):
             )
         self._properties["status"] = value
 
-    def create_resource(self, namespace: "str" = None) -> "SubjectRulesReviewStatus":
+    def create_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "SubjectRulesReviewStatus":
         """
         Creates the SelfSubjectRulesReview in the currently
         configured Kubernetes cluster and returns the status information
@@ -1205,7 +1243,9 @@ class SelfSubjectRulesReview(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def replace_resource(self, namespace: "str" = None) -> "SubjectRulesReviewStatus":
+    def replace_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "SubjectRulesReviewStatus":
         """
         Replaces the SelfSubjectRulesReview in the currently
         configured Kubernetes cluster and returns the status information
@@ -1230,7 +1270,9 @@ class SelfSubjectRulesReview(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def patch_resource(self, namespace: "str" = None) -> "SubjectRulesReviewStatus":
+    def patch_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "SubjectRulesReviewStatus":
         """
         Patches the SelfSubjectRulesReview in the currently
         configured Kubernetes cluster and returns the status information
@@ -1256,7 +1298,7 @@ class SelfSubjectRulesReview(_kuber_definitions.Resource):
         return output
 
     def get_resource_status(
-        self, namespace: "str" = None
+        self, namespace: typing.Optional["str"] = None
     ) -> "SubjectRulesReviewStatus":
         """
         Returns status information about the given resource within the cluster.
@@ -1280,7 +1322,7 @@ class SelfSubjectRulesReview(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the SelfSubjectRulesReview from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -1300,7 +1342,7 @@ class SelfSubjectRulesReview(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -1329,7 +1371,7 @@ class SelfSubjectRulesReview(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.AuthorizationV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -1347,11 +1389,14 @@ class SelfSubjectRulesReview(_kuber_definitions.Resource):
 
 
 class SelfSubjectRulesReviewSpec(_kuber_definitions.Definition):
-    """ """
+    """
+    SelfSubjectRulesReviewSpec defines the specification for
+    SelfSubjectRulesReview.
+    """
 
     def __init__(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
     ):
         """Create SelfSubjectRulesReviewSpec instance."""
         super(SelfSubjectRulesReviewSpec, self).__init__(
@@ -1396,9 +1441,9 @@ class SubjectAccessReview(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        spec: "SubjectAccessReviewSpec" = None,
-        status: "SubjectAccessReviewStatus" = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        spec: typing.Optional["SubjectAccessReviewSpec"] = None,
+        status: typing.Optional["SubjectAccessReviewStatus"] = None,
     ):
         """Create SubjectAccessReview instance."""
         super(SubjectAccessReview, self).__init__(
@@ -1419,7 +1464,11 @@ class SubjectAccessReview(_kuber_definitions.Resource):
 
     @property
     def metadata(self) -> "ObjectMeta":
-        """ """
+        """
+        Standard list metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         return typing.cast(
             "ObjectMeta",
             self._properties.get("metadata"),
@@ -1427,7 +1476,11 @@ class SubjectAccessReview(_kuber_definitions.Resource):
 
     @metadata.setter
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
-        """ """
+        """
+        Standard list metadata. More info:
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
+        """
         if isinstance(value, dict):
             value = typing.cast(
                 ObjectMeta,
@@ -1481,7 +1534,9 @@ class SubjectAccessReview(_kuber_definitions.Resource):
             )
         self._properties["status"] = value
 
-    def create_resource(self, namespace: "str" = None) -> "SubjectAccessReviewStatus":
+    def create_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "SubjectAccessReviewStatus":
         """
         Creates the SubjectAccessReview in the currently
         configured Kubernetes cluster and returns the status information
@@ -1506,7 +1561,9 @@ class SubjectAccessReview(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def replace_resource(self, namespace: "str" = None) -> "SubjectAccessReviewStatus":
+    def replace_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "SubjectAccessReviewStatus":
         """
         Replaces the SubjectAccessReview in the currently
         configured Kubernetes cluster and returns the status information
@@ -1531,7 +1588,9 @@ class SubjectAccessReview(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def patch_resource(self, namespace: "str" = None) -> "SubjectAccessReviewStatus":
+    def patch_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "SubjectAccessReviewStatus":
         """
         Patches the SubjectAccessReview in the currently
         configured Kubernetes cluster and returns the status information
@@ -1557,7 +1616,7 @@ class SubjectAccessReview(_kuber_definitions.Resource):
         return output
 
     def get_resource_status(
-        self, namespace: "str" = None
+        self, namespace: typing.Optional["str"] = None
     ) -> "SubjectAccessReviewStatus":
         """
         Returns status information about the given resource within the cluster.
@@ -1581,7 +1640,7 @@ class SubjectAccessReview(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the SubjectAccessReview from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -1601,7 +1660,7 @@ class SubjectAccessReview(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -1630,7 +1689,7 @@ class SubjectAccessReview(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.AuthorizationV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -1656,12 +1715,12 @@ class SubjectAccessReviewSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        extra: dict = None,
-        groups: typing.List[str] = None,
-        non_resource_attributes: "NonResourceAttributes" = None,
-        resource_attributes: "ResourceAttributes" = None,
-        uid: str = None,
-        user: str = None,
+        extra: typing.Optional[dict] = None,
+        groups: typing.Optional[typing.List[str]] = None,
+        non_resource_attributes: typing.Optional["NonResourceAttributes"] = None,
+        resource_attributes: typing.Optional["ResourceAttributes"] = None,
+        uid: typing.Optional[str] = None,
+        user: typing.Optional[str] = None,
     ):
         """Create SubjectAccessReviewSpec instance."""
         super(SubjectAccessReviewSpec, self).__init__(
@@ -1828,10 +1887,10 @@ class SubjectAccessReviewStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        allowed: bool = None,
-        denied: bool = None,
-        evaluation_error: str = None,
-        reason: str = None,
+        allowed: typing.Optional[bool] = None,
+        denied: typing.Optional[bool] = None,
+        evaluation_error: typing.Optional[str] = None,
+        reason: typing.Optional[str] = None,
     ):
         """Create SubjectAccessReviewStatus instance."""
         super(SubjectAccessReviewStatus, self).__init__(
@@ -1960,10 +2019,10 @@ class SubjectRulesReviewStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        evaluation_error: str = None,
-        incomplete: bool = None,
-        non_resource_rules: typing.List["NonResourceRule"] = None,
-        resource_rules: typing.List["ResourceRule"] = None,
+        evaluation_error: typing.Optional[str] = None,
+        incomplete: typing.Optional[bool] = None,
+        non_resource_rules: typing.Optional[typing.List["NonResourceRule"]] = None,
+        resource_rules: typing.Optional[typing.List["ResourceRule"]] = None,
     ):
         """Create SubjectRulesReviewStatus instance."""
         super(SubjectRulesReviewStatus, self).__init__(
