@@ -5,12 +5,203 @@ from kuber import kube_api as _kube_api  # noqa: F401
 
 from kuber import definitions as _kuber_definitions  # noqa: F401
 from kuber import _types  # noqa: F401
-from kuber.v1_21.meta_v1 import Condition  # noqa: F401
-from kuber.v1_21.meta_v1 import LabelSelector  # noqa: F401
-from kuber.v1_21.meta_v1 import ListMeta  # noqa: F401
-from kuber.v1_21.meta_v1 import ObjectMeta  # noqa: F401
-from kuber.v1_21.meta_v1 import Status  # noqa: F401
-from kuber.v1_21.meta_v1 import StatusDetails  # noqa: F401
+from kuber.v1_26.meta_v1 import Condition  # noqa: F401
+from kuber.v1_26.meta_v1 import DeleteOptions  # noqa: F401
+from kuber.v1_26.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_26.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_26.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_26.meta_v1 import Status  # noqa: F401
+from kuber.v1_26.meta_v1 import StatusDetails  # noqa: F401
+
+
+class Eviction(_kuber_definitions.Resource):
+    """
+    Eviction evicts a pod from its node subject to certain
+    policies and safety constraints. This is a subresource of
+    Pod.  A request to cause such an eviction is created by
+    POSTing to .../pods/<pod name>/evictions.
+    """
+
+    def __init__(
+        self,
+        delete_options: typing.Optional["DeleteOptions"] = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+    ):
+        """Create Eviction instance."""
+        super(Eviction, self).__init__(api_version="policy/v1", kind="Eviction")
+        self._properties = {
+            "deleteOptions": delete_options
+            if delete_options is not None
+            else DeleteOptions(),
+            "metadata": metadata if metadata is not None else ObjectMeta(),
+        }
+        self._types = {
+            "apiVersion": (str, None),
+            "deleteOptions": (DeleteOptions, None),
+            "kind": (str, None),
+            "metadata": (ObjectMeta, None),
+        }
+
+    @property
+    def delete_options(self) -> "DeleteOptions":
+        """
+        DeleteOptions may be provided
+        """
+        return typing.cast(
+            "DeleteOptions",
+            self._properties.get("deleteOptions"),
+        )
+
+    @delete_options.setter
+    def delete_options(self, value: typing.Union["DeleteOptions", dict]):
+        """
+        DeleteOptions may be provided
+        """
+        if isinstance(value, dict):
+            value = typing.cast(
+                DeleteOptions,
+                DeleteOptions().from_dict(value),
+            )
+        self._properties["deleteOptions"] = value
+
+    @property
+    def metadata(self) -> "ObjectMeta":
+        """
+        ObjectMeta describes the pod that is being evicted.
+        """
+        return typing.cast(
+            "ObjectMeta",
+            self._properties.get("metadata"),
+        )
+
+    @metadata.setter
+    def metadata(self, value: typing.Union["ObjectMeta", dict]):
+        """
+        ObjectMeta describes the pod that is being evicted.
+        """
+        if isinstance(value, dict):
+            value = typing.cast(
+                ObjectMeta,
+                ObjectMeta().from_dict(value),
+            )
+        self._properties["metadata"] = value
+
+    def create_resource(self, namespace: typing.Optional["str"] = None):
+        """
+        Creates the Eviction in the currently
+        configured Kubernetes cluster.
+        """
+        names = ["create_namespaced_eviction", "create_eviction"]
+
+        _kube_api.execute(
+            action="create",
+            resource=self,
+            names=names,
+            namespace=namespace,
+            api_client=None,
+            api_args={"body": self.to_dict()},
+        )
+
+    def replace_resource(self, namespace: typing.Optional["str"] = None):
+        """
+        Replaces the Eviction in the currently
+        configured Kubernetes cluster.
+        """
+        names = ["replace_namespaced_eviction", "replace_eviction"]
+
+        _kube_api.execute(
+            action="replace",
+            resource=self,
+            names=names,
+            namespace=namespace,
+            api_client=None,
+            api_args={"body": self.to_dict(), "name": self.metadata.name},
+        )
+
+    def patch_resource(self, namespace: typing.Optional["str"] = None):
+        """
+        Patches the Eviction in the currently
+        configured Kubernetes cluster.
+        """
+        names = ["patch_namespaced_eviction", "patch_eviction"]
+
+        _kube_api.execute(
+            action="patch",
+            resource=self,
+            names=names,
+            namespace=namespace,
+            api_client=None,
+            api_args={"body": self.to_dict(), "name": self.metadata.name},
+        )
+
+    def get_resource_status(self, namespace: typing.Optional["str"] = None):
+        """This resource does not have a status."""
+        pass
+
+    def read_resource(self, namespace: typing.Optional[str] = None):
+        """
+        Reads the Eviction from the currently configured
+        Kubernetes cluster and returns the low-level definition object.
+        """
+        names = [
+            "read_namespaced_eviction",
+            "read_eviction",
+        ]
+        return _kube_api.execute(
+            action="read",
+            resource=self,
+            names=names,
+            namespace=namespace,
+            api_client=None,
+            api_args={"name": self.metadata.name},
+        )
+
+    def delete_resource(
+        self,
+        namespace: typing.Optional[str] = None,
+        propagation_policy: str = "Foreground",
+        grace_period_seconds: int = 10,
+    ):
+        """
+        Deletes the Eviction from the currently configured
+        Kubernetes cluster.
+        """
+        names = [
+            "delete_namespaced_eviction",
+            "delete_eviction",
+        ]
+
+        body = client.V1DeleteOptions(
+            propagation_policy=propagation_policy,
+            grace_period_seconds=grace_period_seconds,
+        )
+
+        _kube_api.execute(
+            action="delete",
+            resource=self,
+            names=names,
+            namespace=namespace,
+            api_client=None,
+            api_args={"name": self.metadata.name, "body": body},
+        )
+
+    @staticmethod
+    def get_resource_api(
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
+    ) -> "client.PolicyV1Api":
+        """
+        Returns an instance of the kubernetes API client associated with
+        this object.
+        """
+        if api_client:
+            kwargs["apl_client"] = api_client
+        return client.PolicyV1Api(**kwargs)
+
+    def __enter__(self) -> "Eviction":
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        return False
 
 
 class PodDisruptionBudget(_kuber_definitions.Resource):
@@ -21,9 +212,9 @@ class PodDisruptionBudget(_kuber_definitions.Resource):
 
     def __init__(
         self,
-        metadata: "ObjectMeta" = None,
-        spec: "PodDisruptionBudgetSpec" = None,
-        status: "PodDisruptionBudgetStatus" = None,
+        metadata: typing.Optional["ObjectMeta"] = None,
+        spec: typing.Optional["PodDisruptionBudgetSpec"] = None,
+        status: typing.Optional["PodDisruptionBudgetStatus"] = None,
     ):
         """Create PodDisruptionBudget instance."""
         super(PodDisruptionBudget, self).__init__(
@@ -114,7 +305,9 @@ class PodDisruptionBudget(_kuber_definitions.Resource):
             )
         self._properties["status"] = value
 
-    def create_resource(self, namespace: "str" = None) -> "PodDisruptionBudgetStatus":
+    def create_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "PodDisruptionBudgetStatus":
         """
         Creates the PodDisruptionBudget in the currently
         configured Kubernetes cluster and returns the status information
@@ -139,7 +332,9 @@ class PodDisruptionBudget(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def replace_resource(self, namespace: "str" = None) -> "PodDisruptionBudgetStatus":
+    def replace_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "PodDisruptionBudgetStatus":
         """
         Replaces the PodDisruptionBudget in the currently
         configured Kubernetes cluster and returns the status information
@@ -164,7 +359,9 @@ class PodDisruptionBudget(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def patch_resource(self, namespace: "str" = None) -> "PodDisruptionBudgetStatus":
+    def patch_resource(
+        self, namespace: typing.Optional["str"] = None
+    ) -> "PodDisruptionBudgetStatus":
         """
         Patches the PodDisruptionBudget in the currently
         configured Kubernetes cluster and returns the status information
@@ -190,7 +387,7 @@ class PodDisruptionBudget(_kuber_definitions.Resource):
         return output
 
     def get_resource_status(
-        self, namespace: "str" = None
+        self, namespace: typing.Optional["str"] = None
     ) -> "PodDisruptionBudgetStatus":
         """
         Returns status information about the given resource within the cluster.
@@ -214,7 +411,7 @@ class PodDisruptionBudget(_kuber_definitions.Resource):
             output.from_dict(_kube_api.to_kuber_dict(response.status))
         return output
 
-    def read_resource(self, namespace: str = None):
+    def read_resource(self, namespace: typing.Optional[str] = None):
         """
         Reads the PodDisruptionBudget from the currently configured
         Kubernetes cluster and returns the low-level definition object.
@@ -234,7 +431,7 @@ class PodDisruptionBudget(_kuber_definitions.Resource):
 
     def delete_resource(
         self,
-        namespace: str = None,
+        namespace: typing.Optional[str] = None,
         propagation_policy: str = "Foreground",
         grace_period_seconds: int = 10,
     ):
@@ -263,7 +460,7 @@ class PodDisruptionBudget(_kuber_definitions.Resource):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.PolicyV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -288,8 +485,8 @@ class PodDisruptionBudgetList(_kuber_definitions.Collection):
 
     def __init__(
         self,
-        items: typing.List["PodDisruptionBudget"] = None,
-        metadata: "ListMeta" = None,
+        items: typing.Optional[typing.List["PodDisruptionBudget"]] = None,
+        metadata: typing.Optional["ListMeta"] = None,
     ):
         """Create PodDisruptionBudgetList instance."""
         super(PodDisruptionBudgetList, self).__init__(
@@ -361,7 +558,7 @@ class PodDisruptionBudgetList(_kuber_definitions.Collection):
 
     @staticmethod
     def get_resource_api(
-        api_client: client.ApiClient = None, **kwargs
+        api_client: typing.Optional[client.ApiClient] = None, **kwargs
     ) -> "client.PolicyV1Api":
         """
         Returns an instance of the kubernetes API client associated with
@@ -386,9 +583,10 @@ class PodDisruptionBudgetSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        max_unavailable: typing.Union[str, int, None] = None,
-        min_available: typing.Union[str, int, None] = None,
-        selector: "LabelSelector" = None,
+        max_unavailable: typing.Optional[typing.Union[str, int, None]] = None,
+        min_available: typing.Optional[typing.Union[str, int, None]] = None,
+        selector: typing.Optional["LabelSelector"] = None,
+        unhealthy_pod_eviction_policy: typing.Optional[str] = None,
     ):
         """Create PodDisruptionBudgetSpec instance."""
         super(PodDisruptionBudgetSpec, self).__init__(
@@ -398,11 +596,15 @@ class PodDisruptionBudgetSpec(_kuber_definitions.Definition):
             "maxUnavailable": max_unavailable if max_unavailable is not None else None,
             "minAvailable": min_available if min_available is not None else None,
             "selector": selector if selector is not None else LabelSelector(),
+            "unhealthyPodEvictionPolicy": unhealthy_pod_eviction_policy
+            if unhealthy_pod_eviction_policy is not None
+            else "",
         }
         self._types = {
             "maxUnavailable": (_types.integer_or_string, None),
             "minAvailable": (_types.integer_or_string, None),
             "selector": (LabelSelector, None),
+            "unhealthyPodEvictionPolicy": (str, None),
         }
 
     @property
@@ -483,6 +685,85 @@ class PodDisruptionBudgetSpec(_kuber_definitions.Definition):
             )
         self._properties["selector"] = value
 
+    @property
+    def unhealthy_pod_eviction_policy(self) -> str:
+        """
+        UnhealthyPodEvictionPolicy defines the criteria for when
+        unhealthy pods should be considered for eviction. Current
+        implementation considers healthy pods, as pods that have
+        status.conditions item with type="Ready",status="True".
+
+        Valid policies are IfHealthyBudget and AlwaysAllow. If no
+        policy is specified, the default behavior will be used,
+        which corresponds to the IfHealthyBudget policy.
+
+        IfHealthyBudget policy means that running pods
+        (status.phase="Running"), but not yet healthy can be evicted
+        only if the guarded application is not disrupted
+        (status.currentHealthy is at least equal to
+        status.desiredHealthy). Healthy pods will be subject to the
+        PDB for eviction.
+
+        AlwaysAllow policy means that all running pods
+        (status.phase="Running"), but not yet healthy are considered
+        disrupted and can be evicted regardless of whether the
+        criteria in a PDB is met. This means perspective running
+        pods of a disrupted application might not get a chance to
+        become healthy. Healthy pods will be subject to the PDB for
+        eviction.
+
+        Additional policies may be added in the future. Clients
+        making eviction decisions should disallow eviction of
+        unhealthy pods if they encounter an unrecognized policy in
+        this field.
+
+        This field is alpha-level. The eviction API uses this field
+        when the feature gate PDBUnhealthyPodEvictionPolicy is
+        enabled (disabled by default).
+        """
+        return typing.cast(
+            str,
+            self._properties.get("unhealthyPodEvictionPolicy"),
+        )
+
+    @unhealthy_pod_eviction_policy.setter
+    def unhealthy_pod_eviction_policy(self, value: str):
+        """
+        UnhealthyPodEvictionPolicy defines the criteria for when
+        unhealthy pods should be considered for eviction. Current
+        implementation considers healthy pods, as pods that have
+        status.conditions item with type="Ready",status="True".
+
+        Valid policies are IfHealthyBudget and AlwaysAllow. If no
+        policy is specified, the default behavior will be used,
+        which corresponds to the IfHealthyBudget policy.
+
+        IfHealthyBudget policy means that running pods
+        (status.phase="Running"), but not yet healthy can be evicted
+        only if the guarded application is not disrupted
+        (status.currentHealthy is at least equal to
+        status.desiredHealthy). Healthy pods will be subject to the
+        PDB for eviction.
+
+        AlwaysAllow policy means that all running pods
+        (status.phase="Running"), but not yet healthy are considered
+        disrupted and can be evicted regardless of whether the
+        criteria in a PDB is met. This means perspective running
+        pods of a disrupted application might not get a chance to
+        become healthy. Healthy pods will be subject to the PDB for
+        eviction.
+
+        Additional policies may be added in the future. Clients
+        making eviction decisions should disallow eviction of
+        unhealthy pods if they encounter an unrecognized policy in
+        this field.
+
+        This field is alpha-level. The eviction API uses this field
+        when the feature gate PDBUnhealthyPodEvictionPolicy is
+        enabled (disabled by default).
+        """
+        self._properties["unhealthyPodEvictionPolicy"] = value
+
     def __enter__(self) -> "PodDisruptionBudgetSpec":
         return self
 
@@ -499,13 +780,13 @@ class PodDisruptionBudgetStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
-        conditions: typing.List["Condition"] = None,
-        current_healthy: int = None,
-        desired_healthy: int = None,
-        disrupted_pods: dict = None,
-        disruptions_allowed: int = None,
-        expected_pods: int = None,
-        observed_generation: int = None,
+        conditions: typing.Optional[typing.List["Condition"]] = None,
+        current_healthy: typing.Optional[int] = None,
+        desired_healthy: typing.Optional[int] = None,
+        disrupted_pods: typing.Optional[dict] = None,
+        disruptions_allowed: typing.Optional[int] = None,
+        expected_pods: typing.Optional[int] = None,
+        observed_generation: typing.Optional[int] = None,
     ):
         """Create PodDisruptionBudgetStatus instance."""
         super(PodDisruptionBudgetStatus, self).__init__(
